      PROGRAM PARSCIF
C-----Release October 1994
C************************************************************************
C*                           Program PARSTCIF                           *
C*                                                                      *
C*                            by M. Nardelli                            *
C*                                                                      *
C* Dipartimento di Chimica Generale ed Inorganica, Chimica Analitica,   *
C*        Chimica Fisica della Universita' degli Studi di Parma         *
C* Centro di Studio per la Strutturistica Diffrattometrica, CNR (Parma) *
C*             Viale delle Scienze 78, 43100 Parma (Italy)              *
C*                                                                      *
C* This routine sets up a CIF file from the output of PARST (Comput.    *
C* Chem. (1983).7,95-98), according to the rules explained by S.R. Hall,*
C* F.H. Allen and I.D. Brown in:                                        *
C*                                                                      *
C* "The Crystallographic Information File (CIF): a New Standard Archive *
C*  File for Crystallography" [Acta Cryst.(1991). A47, 655-685]         *
C*                                                                      *
C* The file can be used for submitting structural papers to Acta Cryst. *
C* by Electronic mail according to the instructions given in Acta Cryst.*
C* (1994). C50, 145-159.                                                *
C*                                                                      *
C* Standard editing should be used to introduce missing information and *
C* to correct some points, like to eliminate white space with e.s.d.    *
C* [e.g. 0.004( 9) must be given as 0.0044(9)]. E.s.d.'s in parentheses *
C* must be given as integer.                                            *
C*                                                                      *
C* Tables cannot be entered as a separate field; these should be        *
C* entered within the _publ_section_discussion field.                   *
C*                                                                      *
C* Careful reading of the above articles is strongly recommended.       *
C*                                                                      *
C* Copyright of the STAR specifications is held by the International    *
C* Union of Crystallography, 5 Abbey Square, Chester, U.K., and a       *
C* patent has been applied for to cover the STAR file process.          *
C*                                                                      *
C* NB - In using program PARST use must be made of the options giving   *
C*      an output compatible as input for this program, i.e. crystal    *
C*      data must be printed (KY=1), anisotropic atomic displacements   *
C*      must be considered (KOR=2).                                     *
C*    - The first twenty characters of the title (first record) should  *
C*      be devoted to the chemical formula of the compound; the first   *
C*      twenty characters of the second card must be devoted to the     *
C*      Hermann-Mauguin space group symbol                              *
C*    - The anisotropic atoms must be grouped and come before the iso-  *
C*      tropic ones; the hydrogen must be isotropic and come last.      *
C*    - Check the numbers of the atoms of each type in the unit cell,   *
C*      as the program calculates them from the table of the atomic     *
C*      coordinates and the number of asymmetric units in the unit cell;*
C*      so, if some atoms were not found or disordered atoms are        *
C*      present, the values given by the program can be inconsistent.   *
C************************************************************************
      CHARACTER*1 FRM(20),DUM(10),SPG(20),ATM(200,4),STR1(7),STR2(4),
     1 ATD1(500,4),ATD2(500,4),ATM1(4),ATM2(4),ATMH(200,4),STR3(11),
     2 AAM,STR6(10),ATA1(600,4),ATA2(600,4),ATA3(600,4),ABH1(200,4),
     3 ABH2(200,4),ABH(4),AAAA(4),ABB(4),TYP(2),AA(2),SAT(20,2),QS,
     4 SPC(20,2),STR7(4),ATM3(4)
      CHARACTER*3 SSTR
      CHARACTER*5 STR4
      CHARACTER*4 STR5
      CHARACTER*12 NMT
      CHARACTER*29 SC1
      DIMENSION AC(200,3),ISA(200,3),C(3),SC(3),A(3),SA(3),U(200,6),
     1 ISU(200,6),IU(6),UQ(200),ISUQ(200),RR(200),DST(500),ISDS(500),
     2 X(3),ISX(3),ACH(200,3),ISAH(200,3),ICDU(200),ANG(600),SANG(600),
     3 ISAP(3),NSP(20),B(200),SB(200),UU(6),IUS(6)
      COMMON/GRP1/ATM
     1      /GRP2/STR3
      DATA STR1/' ','D','I','S','P','L','A'/
      DATA STR2/' ','N','U','M'/
      DATA STR6/' ','I','N','T','E','R','A','T','O','M'/
      DATA STR7/' ','T','H','E'/
      SC1='Int. Tab. C, 4.2.6.8, 6.1.1.4'
      CALL INTERIO
C-----Read name of compound and formula
      READ(13,105)FRM,SPG,DUM,DUM
105   FORMAT(20A1/20A1/10A1/10A1)
C-----Read lattice constants with e.s.d.'s
      READ(13,106)C(1),SC(1),A(1),SA(1),C(2),SC(2),A(2),SA(2),
     1 C(3),SC(3),A(3),SA(3),V,SV
106   FORMAT(5X,F7.4,1X,F6.4,33X,F6.2,1X,F4.2/5X,F7.4,1X,F6.4,33X,
     1 F6.2,1X,F4.2/5X,F7.4,1X,F6.4,33X,F6.2,1X,F4.2/5X,F9.2,1X,F5.2)
      DO 1 I=1,10
1     READ(13,'(10A1)')DUM
C-----Read M, Z, Dx, F000, mu, lambda, N=number of atoms
      READ(13,107)AM,Z,DX,F000,AMU,ALA,DUM,N
107   FORMAT(10X,F10.3/13X,F6.2/12X,F9.4/10X,F8.1/12X,F8.3/15X,F9.7/
     1 10A1/19X,I3)
      AMU=AMU*0.1
      DO 2 I=1,3
2     READ(13,'(10A1)')DUM
C-----Read atomic coordinates with e.s.d.s
      NP=0
      NH=0
      DO 3 I=1,N
      READ(13,108)ATM1,(X(K),ISX(K),K=1,3)
108   FORMAT(1X,4A1,6X,3(F8.5,1X,I5,1X,5X))
C-----Separate non-H from H atoms
      CALL HDR(ATM1,KD)
      IF(KD.EQ.0)THEN
      NP=NP+1
      DO 16 J=1,3
      ATM(NP,J)=ATM1(J)
      AC(NP,J)=X(J)
16    ISA(NP,J)=ISX(J)
      ATM(NP,4)=ATM1(4)
      ELSE
      NH=NH+1
      DO 17 J=1,3
      ATMH(NH,J)=ATM1(J)
      ACH(NH,J)=X(J)
17    ISAH(NH,J)=ISX(J)
      ATMH(NH,4)=ATM1(4)
      ENDIF
3     CONTINUE
C-----Choose the atomic species
      NS=0
      DO 63 I=1,NP
      DO 59 J=1,11
      IF(ATM(I,2).NE.STR3(J))GO TO 59
      AA(2)=' '
      GO TO 60
59    CONTINUE
      AA(2)=ATM(I,2)
60    IF(NS.GT.0) GO TO 66
      NS=NS+1
      SAT(NS,1)=ATM(I,1)
      SAT(NS,2)=AA(2)
      GO TO 63
66    DO 61 J=1,NS
      IF(SAT(J,1).NE.ATM(I,1).OR.SAT(J,2).NE.AA(2)) GO TO 61
      GO TO 63
61    CONTINUE
62    NS=NS+1
      SAT(NS,1)=ATM(I,1)
      SAT(NS,2)=AA(2)
63    CONTINUE
      IF(NH.EQ.0) GO TO 64
      NS=NS+1
      SAT(NS,1)='H'
      SAT(NS,2)=' '
C-----Read dummy lines
64    NN=7
4     READ(13,'(10A1)')DUM
      CALL MINUMA1(NN,DUM)
      DO 5 J=1,NN
      IF(DUM(J).NE.STR1(J))GO TO 4
5     CONTINUE
      READ(13,'(10A1)')DUM
      READ(13,'(10A1)')DUM
C-----Read atomic anisotropic displacement parameters with e.s.d.s
      NPP=0
      DO 6 I=1,N
      READ(13,119)(IU(J),ISU(I,J),J=1,6)
119   FORMAT(5X,6(I5,1X,I4,1X))
      IF(IU(2).EQ.0)THEN
      ICDU(I)=0
      ELSE
      ICDU(I)=1
      NPP=NPP+1
      ENDIF
      DO 6 J=1,6
      IF(IU(J).EQ.0)THEN
      U(I,J)=0.0
      ELSE
      U(I,J)=IU(J)*1E-4
      ENDIF
6     CONTINUE
      DO 7 I=1,4
7     READ(13,'(10A1)')DUM
C-----Read Ueq, sigma(Ueq), Beq, sigma(Beq), Rmax./Rmin.
      DO 8 I=1,NPP
      READ(13,120)IUQ,ISUQ(I),B(I),SB(I),RR(I)
120   FORMAT(38X,I5,1X,I4,2X,F5.2,1X,F4.2,1X,F7.2)
8     UQ(I)=IUQ*1E-4
      IF(NPP.EQ.NP)GO TO 71
      DO 69 I=NPP+1,NP
      UQ(I)=U(I,1)
69    ISUQ(I)=ISU(I,1)
C-----Read dummy lines
71    DO 9 I=1,5
9     READ(13,'(10A1)')DUM
      ND=0
10    READ(13,'(4A1)')(DUM(K),K=1,4)
      NN=4
      CALL MINUMA1(NN,DUM)
      DO 12 J=1,NN
      IF(DUM(J).NE.STR2(J))GO TO 48
12    CONTINUE
      GO TO 14
48    DO 57 J=1,NN
      IF(DUM(J).NE.STR7(J))GO TO 13
57    CONTINUE
      GO TO 10
13    ND=ND+1
      BACKSPACE(13)
C-----Read bond distances with e.s.d.'s
      READ(13,121)(ATD1(ND,I),I=1,4),(ATD2(ND,I),I=1,4),DST(ND),
     1 ISDS(ND)
121   FORMAT(1X,4A1,3X,4A1,4X,F7.4,1X,I4)
      GO TO 10
14    CONTINUE
C-----Read dummy lines
      DO 35 I=1,5
35    READ(13,'(10A1)')DUM
      NAN=0
36    READ(13,'(4A1)')(DUM(K),K=1,4)
      NN=4
      CALL MINUMA1(NN,DUM)
      DO 37 J=1,NN
      IF(DUM(J).NE.STR2(J))GO TO 38
37    CONTINUE
      GO TO 39
38    NAN=NAN+1
      BACKSPACE(13)
C-----Read bond angles with e.s.d.'s
      READ(13,134)(ATA1(NAN,I),I=1,4),(ATA2(NAN,I),I=1,4),(ATA3(NAN,I),
     1 I=1,4),ANG(NAN),SANG(NAN)
134   FORMAT(1X,4A1,2X,4A1,2X,4A1,11X,F6.2,5X,F4.2)
      GO TO 36
39    CONTINUE
C-----CIF text for publication
      WRITE(15,100)
100   FORMAT('data_X'//'_audit_creation_date',16X,'?'/
     1 '_audit_creation_method',10X,'''PARSTCIF'''/
     2 '_audit_update_record',16X,'?'//
     2 '_publ_contact_author'/';'/5X,'Prof. Mario Nardelli'/
     3 5X,'Dipartimento di Chimica Generale ed Inorganica,'/
     4 5X,'    Chimica Analitica, Chimica Fisica'/
     4 5X,'Universit\`a degli Studi di Parma'/
     5 5X,'Viale delle Scienze 78'/5X,'I-43100 Parma'/5X,'Italy'/';')
      WRITE(15,101)
101   FORMAT('_publ_contact_letter'/';'/5X,'Date'//
     1 5X,'Mr. Peter R. Strickland'/5X,'Managing Editor'/
     2 5X,'Acta Crystallographica'/5X,'IUCr Office'/
     3 5X,'5 Abbey Square'/5X,'Chester    CH1 2HU'/5X,'U. K.'//
     4 5X,'Re: Paper submitted to Acta Cryst.'//
     5 5X,'Dear Mr. Strickland,'/
     6 18X,'Attached is a manuscript with the after-mentioned title'/
     7 5X,'and authors, submitted for publication in Acta ',
     8 'Crystallographica C.'/18X,'The requested hard copy material ',
     9 'will be sent by'/5X,'ordinary mail.'//35X,'Yours Sincerely'/
     1 35X,'Mario Nardelli'//';'/'_publ_contact_author_phone',10X,
     2 '''[01039]521 905 433'''/'_publ_contact_author_fax  ',10X,
     3 '''[01039]521 905 557'''/'_publ_contact_author_email',10X,
     4 '''nardelli@ipruniv.cce.unipr.it'''/'_publ_requested_journal',
     5 13X,'''Acta Cryst. C'''/'_publ_requested_coeditor_name',14X,
     6 '?'//'_publ_section_title'/';'/8X,'Structure of ....'/';')
      WRITE(15,102)
102   FORMAT('loop_'/4X,'_publ_author_name'/4X,'_publ_author_',
     1 'address'//5X,'''Mario Nardelli'''/';',4X,'Dipartimento di ',
     2 'Chimica Generale ed Inorganica, '/5X,'    Chimica Analitica, ',
     3 'Chimica Fisica'/5X,'Universit\`a degli Studi di Parma'/
     4 5X,'Centro di Studio per la Strutturistica ',
     5 'Diffrattometrica del CNR'/5X,'Viale delle Scienze 78'/
     6 5X,'I-43100 Parma'/5X,'Italy'/';'/)
      WRITE(15,103)
103   FORMAT('_publ_section_abstract'/';'/'......'/';'//'_publ_',
     1 'section_introduction'/';'/'......'/';'//'_publ_section_',
     2 'experimental'/';'/'......'/';'//'_publ_section_comment'/
     3 ';'/'......'/';'//'_publ_section_acknowledgements'/';'/
     4 '......'/';'//'_publ_section_references'/';'/'......'/
     4 ';'//'_publ_section_figure_captions'/';'/'......'/';'//
     5 '_publ_section_table_legends'/';'/'......'/';'/)
C-----Print CIF data
      WRITE(15,104)
104   FORMAT('#',26('-'),' data section of block ',27('-')/'data_Y'//
     1 'loop_'/'_geom_bond_atom_site_label_1'/
     2 '_geom_bond_atom_site_label_2'/
     3 '_geom_bond_distance'/'_geom_bond_publ_flag'/)
C-----Print the table of bond distances
      NAH=0
      DO 34 I=1,ND
      DO 11 L=1,4
      ATM1(L)=ATD1(I,L)
11    ATM2(L)=ATD2(I,L)
      CALL HDR(ATM1,KD)
      IF(KD.EQ.0)GO TO 40
      SSTR='no '
      NAH=NAH+1
      DO 45 K=1,4
      ABH1(NAH,K)=ATD1(I,K)
45    ABH2(NAH,K)=ATD2(I,K)
      IF(ISDS(I).LT.10)THEN
      WRITE(15,131)(ATD1(I,L),L=1,4),(ATD2(I,L),L=1,4),DST(I),ISDS(I),
     1 SSTR
131   FORMAT(22X,4A1,2X,4A1,4X,F6.4,'(',I1,')',2X,A3)
      ELSEIF(ISDS(I).GE.10.AND.ISDS(I).LT.94)THEN
      ISDS(I)=(ISDS(I)+5)/10
      WRITE(15,132)(ATD1(I,L),L=1,4),(ATD2(I,L),L=1,4),DST(I),ISDS(I),
     1 SSTR
132   FORMAT(22X,4A1,2X,4A1,4X,F5.3,'(',I1,')',3X,A3)
      ELSE
      ISDS(I)=(ISDS(I)+5)/100
      WRITE(15,133)(ATD1(I,L),L=1,4),(ATD2(I,L),L=1,4),DST(I),ISDS(I),
     1 SSTR
133   FORMAT(22X,4A1,2X,4A1,4X,F4.2,'(',I1,')',4X,A3)
      ENDIF
40    CALL HDR(ATM2,KD)
      IF(KD.EQ.0)GO TO 41
      SSTR='no '
      NAH=NAH+1
      DO 46 K=1,4
      ABH1(NAH,K)=ATD2(I,K)
46    ABH2(NAH,K)=ATD1(I,K)
      IF(ISDS(I).LT.10)THEN
      WRITE(15,131)(ATD1(I,L),L=1,4),(ATD2(I,L),L=1,4),DST(I),ISDS(I),
     1 SSTR
      ELSEIF(ISDS(I).LT.94)THEN
      ISDS(I)=(ISDS(I)+5)/10
      WRITE(15,132)(ATD1(I,L),L=1,4),(ATD2(I,L),L=1,4),DST(I),ISDS(I),
     1 SSTR
      ELSE
      ISDS(I)=(ISDS(I)+5)/100
      WRITE(15,133)(ATD1(I,L),L=1,4),(ATD2(I,L),L=1,4),DST(I),ISDS(I),
     1 SSTR
      ENDIF
      GO TO 34
41    SSTR='yes'
      IF(ISDS(I).LT.10)THEN
      WRITE(15,131)(ATD1(I,L),L=1,4),(ATD2(I,L),L=1,4),DST(I),ISDS(I),
     1 SSTR
      ELSEIF(ISDS(I).LT.94)THEN
      ISDS(I)=(ISDS(I)+5)/10
      WRITE(15,132)(ATD1(I,L),L=1,4),(ATD2(I,L),L=1,4),DST(I),ISDS(I),
     1 SSTR
      ELSE
      ISDS(I)=(ISDS(I)+5)/100
      WRITE(15,133)(ATD1(I,L),L=1,4),(ATD2(I,L),L=1,4),DST(I),ISDS(I),
     1 SSTR
      ENDIF
34    CONTINUE
C-----Print the table of bond angles
      WRITE(15,137)
137   FORMAT(//'loop_'/'_geom_angle_atom_site_label_1'/
     1 '_geom_angle_atom_site_label_2'/'_geom_angle_atom_site_label_3'/
     2 '_geom_angle'/'_geom_angle_publ_flag'/)
      DO 42 I=1,NAN
      DO 15 L=1,4
      ATM1(L)=ATA1(I,L)
      ATM2(L)=ATA2(I,L)
      ATM3(L)=ATA3(I,L)
      CALL HDR(ATM1,KD1)
      CALL HDR(ATM2,KD2)
15    CALL HDR(ATM3,KD3)
      SSTR='no '
      IF(KD1.EQ.0.AND.KD2.EQ.0.AND.KD3.EQ.0) SSTR='yes'
      IF((SANG(I)+0.05).LT.1.0)THEN
      ISANG=SANG(I)*10+0.5
      WRITE(15,135)(ATA1(I,L),L=1,4),(ATA2(I,L),L=1,4),(ATA3(I,L),
     1 L=1,4),ANG(I),ISANG,SSTR
135   FORMAT(23X,4A1,2X,4A1,2X,4A1,4X,F5.1,'(',I1,')',2X,A3)
      ELSE
      IANG=ANG(I)+0.5
      ISANG=SANG(I)+0.5
      WRITE(15,136)(ATA1(I,L),L=1,4),(ATA2(I,L),L=1,4),(ATA3(I,L),
     1 L=1,4),IANG,ISANG,SSTR
136   FORMAT(23X,4A1,2X,4A1,2X,4A1,4X,I3,'(',I1,')',4X,A3)
      ENDIF
42    CONTINUE
      WRITE(15,109)FRM,AM
109   FORMAT(/'_chemical_name_systematic'/';'/'.....'/';'//'_chemical_'
     1 ,'formula_analytical',12X,'''',20A1,''''/'_chemical_formula_',
     2 'moiety',24X,'?'/'_chemical_formula_structural',20X,'?'/
     3 '_chemical_formula_sum',27X,'?'/'_chemical_formula_weight',18X,
     4 F9.2/'_chemical_melting_point',25X,'?'//
     5 '_computing_data_collection',22X,'?'/
     6 '_computing_cell_refinement',22X,'?'/
     7 '_computing_data_reduction',23X,'?'/
     8 '_computing_structure_solution',19X,'?'/
     9 '_computing_structure_refinement',17X,'?'/
     1 '_computing_molecular_graphics',19X,'?'/
     2 '_computing_publication_material'/';'/
     3 ' PARST (Nardelli, 1983); PARSTCIF (Nardelli, 1991)'/';')
      DO 70 I=1,3
      KKD1=1
      KKD2=I
      XX=C(I)
      SXX=SC(I)
70    CALL ROUNDOFF(KKD1,KKD2,XX,SXX)
      DO 72 I=1,3
      KKD1=2
      KKD2=I
      XX=A(I)
      SXX=SA(I)
72    CALL ROUNDOFF(KKD1,KKD2,XX,SXX)
      KKD1=3
      KKD2=0
      CALL ROUNDOFF(KKD1,KKD2,V,SV)
      WRITE(15,110)Z
110   FORMAT('_cell_formula_units_Z',25X,F5.2/
     1 '_cell_measurement_temperature',19X,'?'/
     2 '_cell_measurement_radiation',21X,'?'/
     3 '_cell_measurement_wavelength',20X,'?'/
     4 '_cell_measurement_reflns_used',19X,'?'/
     5 '_cell_measurement_theta_min',21X,'?'/
     6 '_cell_measurement_theta_max',21X,'?'/)
      WRITE(15,111)SPG
111   FORMAT('_symmetry_cell_setting',26X,'?'/
     1 '_symmetry_space_group_name_H-M',15X,'''',20A1,''''/
     2 '_symmetry_space_group_name_Hall',17X,'?'/
     3 '_symmetry_Int_Tables_number',21X,'?'//
     4 'loop_'/'_symmetry_equiv_pos_as_xyz'/
     5 '''x, y, z'''/'''.......'''/)
      WRITE(15,112)DX,F000
112   FORMAT('_chemical_compound_source'/';'/'......'/';'/
     1 '_exptl_crystal_description'/';'/'......'/';'/'_exptl_crystal_',
     2 'colour',27X,'?'/'_exptl_crystal_size_max',25X,'?'/
     3 '_exptl_crystal_size_mid',25X,'?'/
     4 '_exptl_crystal_size_min',25X,'?'/
     5 '_exptl_crystal_density_diffrn',14X,F9.4/
     6 '_exptl_crystal_density_meas',21X,'?'/
     7 '_exptl_crystal_density_method',19X,'?'/
     8 '_exptl_crystal_F_000',24X,F8.1/)
      WRITE(15,113)AMU
113   FORMAT('_exptl_absorpt_coefficient_mu',14X,F8.4/
     1 '_exptl_absorpt_correction_type',18X,'?'/
     2 '_exptl_absorpt_correction_T_min',17X,'?'/
     3 '_exptl_absorpt_correction_T_max',17X,'?'/)
      WRITE(15,114)ALA
114   FORMAT('_diffrn_special_details'/';'/'.......'/';'//
     1 '_diffrn_ambient_temperature',21X,'?'/
     2 '_diffrn_radiation_wavelength',17X,F7.5/
     3 '_diffrn_radiation_type',26X,'?'/
     4 '_diffrn_radiation_source',24X,'?'/
     3 '_diffrn_radiation_monochromator',17X,'?'/
     4 '_diffrn_radiation_detector',22X,'?'/
     5 '_diffrn_measurement_device',22X,'?'/
     6 '_diffrn_measurement_method',22X,'?'/)
      WRITE(15,115)
115   FORMAT('_diffrn_standards_number',24X,'?'/
     1 '_diffrn_standards_interval_count',16X,'?'/
     2 '_diffrn_standards_interval_time',17X,'?'/
     3 '_diffrn_standards_decay_%',23X,'?'//'loop_'/4X,
     4 '_diffrn_standard_refln_index_h'/4X,'_diffrn_standard_refln_',
     5 'index_k'/4X,'_diffrn_standard_refln_index_l'/12X,'?  ?  ?'/
     6 'loop_'/4X,'_diffrn_attenuator_code'/
     7 4X,'_diffrn_attenuator_scale'/12X,'?   ?'/)
      WRITE(15,116)
116   FORMAT('_reflns_number_total',28X,'?'/
     1 '_reflns_number_observed',25X,'?'/
     2 '_reflns_observed_criterion',22X,'?'/
     3 '_diffrn_reflns_av_R_equivalents',17X,'?'/
     4 '_diffrn_reflns_av_sigmaI/netI',19X,'?'/
     5 '_diffrn_reflns_limit_h_min',22X,'?'/
     6 '_diffrn_reflns_limit_h_max',22X,'?'/
     7 '_diffrn_reflns_limit_k_min',22X,'?'/
     8 '_diffrn_reflns_limit_k_max',22X,'?'/
     9 '_diffrn_reflns_limit_l_min',22X,'?'/
     1 '_diffrn_reflns_limit_l_max',22X,'?'/
     2 '_diffrn_reflns_number',27X,'?'/
     3 '_diffrn_reflns_theta_min',24X,'?'/
     4 '_diffrn_reflns_theta_max',24X,'?'/
     5 '_reflns_d_resolution_high',23X,'?'//
     6 '_diffrn_reflns_reduction_process'/';'/'......'/';'/)
C-----Print the anomalous dispersion coefficients
      WRITE(15,117)
117   FORMAT('loop_'/4X,'_atom_type_symbol'/4X,'_atom_type_number_',
     1 'in_cell'/4X,'_atom_type_description'/4X,'_atom_type_scat_',
     2 'dispersion_real'/4X,'_atom_type_scat_dispersion_imag'/
     3 4X,'_atom_type_scat_source'/'#'/'# symbol number description',
     4 6X,'f''',5X,'f''''',8X,'source'/'#')
C-----Prepare for the table of atomic coordinates
      WRITE(*,156)
156   FORMAT(/' Key in the number of asymmetric units in the unit ',
     1 'cell'/' ?>')
      READ(*,*)Z1
      DO 65 I=1,NS
      AA(1)=SAT(I,1)
      AA(2)=SAT(I,2)
      CALL ANOMDIS(AA,ALA,F1,F2,NMT)
      CALL NUMAT(NP,NH,Z1,SPC,NSP)
      DO 67 J=1,20
      IF(AA(1).NE.SPC(J,1).OR.AA(2).NE.SPC(J,2))GO TO 67
      NUM=NSP(J)
      GO TO 68
67    CONTINUE
68    CALL MINUSC(AA(2))
65    WRITE(15,138)AA,NUM,NMT,F1,F2,SC1
138   FORMAT(3X,'''',2A1,'''',1X,I5,2X,'''',A12,'''',2(F8.4),1X,
     1 '''',A29,'''')
      WRITE(15,118)
118   FORMAT(/'loop_'/4X,'_atom_site_label'/4X,'_atom_site_fract_x'/
     1 4X,'_atom_site_fract_y'/4X,'_atom_site_fract_z'/
     2 4X,'_atom_site_U_iso_or_equiv'/4X,'_atom_site_thermal_displace_',
     3 'type'/4X,'_atom_site_type_symbol'/4X,'_atom_site_calc_flag'/
     4 4X,'_atom_site_calc_attached_atom'/
     5 4X,'_atom_site_aniso_ratio'/'#')
      WRITE(15,122)
122   FORMAT('#  R=Rmax./Rmin.=ratio of the maximum and minimum'/
     1 '#',16X,'principal axes of atomic displacement ellipsoids'//
     2 '#',21X,'Table of coordinates'/'#',21X,20('-')/
     3 '#'/'#label',4X,'x/a',9X,'y/b',9X,'z/c',8X,'Ueq',7X,'tmf',2X,
     4 'typ',1X,'calc att',3X,'R'/)
C-----Print the atomic coordinate table (anisotropic non-H atoms)
      DO 18 I=1,NP
      TYP(1)=ATM(I,1)
      TYP(2)=ATM(I,2)
      DO 20 J=1,11
      IF(TYP(2).EQ.STR3(J))GO TO 21
20    CONTINUE
      GO TO 22
21    TYP(2)=' '
22    CALL MINUSC(TYP(2))
      STR4='aniso'
      IF(ICDU(I).EQ.0)STR4='iso  '
      STR5=' .  '
      IF(ISA(I,1).EQ.0.AND.ISA(I,2).EQ.0.AND.ISA(I,3).EQ.0)STR5='calc'
      DO 54 L=1,4
      AAAA(L)=ATM(I,L)
54    ABB(L)=' '
      ABB(1)='.'
      DO 55 K=1,3
      X(K)=AC(I,K)
      ISX(K)=ISA(I,K)
      IF(ISA(I,K).GE.95.AND.ISA(I,K).LT.100)ISA(I,K)=100
      IF(ISA(I,K).GE.995.AND.ISA(I,K).LT.1000)ISA(I,K)=1000
55    CONTINUE
      UE=UQ(I)
      ISE=ISUQ(I)
      DO 58 K=1,3
      IF(ISX(K).LT.10)GO TO 58
      AAA=ISX(K)
      IF(ISX(K).GE.10.AND.ISX(K).LT.995)ISX(K)=AAA/10+0.5
      IF(ISX(K).GE.995)ISX(K)=AAA/100+0.5
58    CONTINUE
      IF(ISE.LT.10)KDC=2
      IF(ISE.GE.10.AND.ISE.LT.100)KDC=0
      IF(ISE.GE.100.AND.ISE.LT.1000)KDC=1
      IF(ISE.GE.1000)KDC=3
      IF(KDC.EQ.1.OR.KDC.EQ.3)ISE=(ISE+5)/10
      RR1=RR(I)
      CALL TABCOOR(I,RR1,KDC,ISA,AAAA,X,ISX,UE,ISE,STR4,TYP,STR5,ABB)
18    CONTINUE
C-----Print the atomic coordinate table (H atoms)
      DO 19 I=1,NH
      STR4='aniso'
      IF(ICDU(I+NP).EQ.0)STR4='iso  '
      STR5=' .  '
      IF(ISAH(I,1).EQ.0.AND.ISAH(I,2).EQ.0.AND.ISAH(I,3).EQ.0)
     1 STR5='calc'
      DO 49 J=1,NAH
      DO 50 K=1,4
      IF(ATMH(I,K).NE.ABH1(J,K))GO TO 49
50    CONTINUE
      DO 51 K=1,4
51    ABH(K)=ABH2(J,K)
      GO TO 53
49    CONTINUE
53    DO 56 L=1,4
56    AAAA(L)=ATMH(I,L)
      DO 52 K=1,3
      X(K)=ACH(I,K)
      ISX(K)=ISAH(I,K)
      IF(ISAH(I,K).GE.95.AND.ISAH(I,K).LT.100)ISAH(I,K)=100
      IF(ISAH(I,K).GE.995.AND.ISAH(I,K).LT.1000)ISAH(I,K)=1000
      IF(ISX(K).LT.10)GO TO 52
      AAA=ISX(K)
      IF(ISX(K).GE.10.AND.ISX(K).LT.995)ISX(K)=AAA/10+0.5
      IF(ISX(K).GE.995)ISX(K)=AAA/100+0.5
52    CONTINUE
      UE=U(I+NP,1)
      ISE=ISU(I+NP,1)
      TYP(1)=ATMH(I,1)
      TYP(2)=' '
      IF(ISE.LT.10)KDC=2
      IF(ISE.GE.10.AND.ISE.LT.100)KDC=0
      IF(ISE.GE.100.AND.ISE.LT.1000)KDC=1
      IF(ISE.GE.1000)KDC=3
      IF(KDC.EQ.1.OR.KDC.EQ.3)ISE=(ISE+5)/10
      RR1=1.0
      CALL TABCOOR(I,RR1,KDC,ISAH,AAAA,X,ISX,UE,ISE,STR4,TYP,STR5,ABH)
19    CONTINUE
C-----Occupancy of disordered atoms
C      WRITE(*,151)
C151   FORMAT(/' Are there disordered atoms ? Y/N'/)
C      READ(*,'(A1)')QS
C      IF(QS.EQ.'Y'.OR.QS.EQ.'y')WRITE(15,152)
C152   FORMAT(//'loop_'/'_atom_site_label'/'_atom_site_occupancy'//)
C-----Print anisotropic displacement parameters
      WRITE(15,125)
125   FORMAT('loop_'/4X,'_atom_site_aniso_label'/4X,'_atom_site_',
     1 'aniso_U_11'/4X,'_atom_site_aniso_U_22'/4X,'_atom_site_aniso_',
     2 'U_33'/4X,'_atom_site_aniso_U_12'/4X,'_atom_site_aniso_U_13'/
     3 4X,'_atom_site_aniso_U_23'//'#label',3X,'U11',9X,'U22',9X,
     4 'U33',9X,'U23',9X,'U13',9X,'U12'/)
      DO 23 I=1,N
      IF(U(I,2).EQ.0.0.AND.U(I,3).EQ.0.0) GO TO 23
      DO 32 K=1,4
32    AAAA(K)=ATM(I,K)
      DO 33 L=1,6
      UU(L)=U(I,L)
33    IUS(L)=ISU(I,L)
      CALL WRTU(AAAA,UU,IUS)
23    CONTINUE
C-----Details of refinement
      WRITE(15,127)
127   FORMAT(/'_refine_special_details'/';'/'......'/';'/
     1 '_atom_sites_solution_primary',20X,'?'/
     2 '_atom_sites_solution_secondary',18X,'?'/
     3 '_atom_sites_solution_hydrogens',18X,'?'/
     4 '_refine_ls_structure_factor_coef',16X,'?'/
     5 '_refine_ls_matrix_type',26X,'?'/
     6 '_refine_ls_weighting_scheme',21X,'?'/
     7 '_refine_ls_hydrogen_treatment',19X,'?'/
     8 '_refine_ls_extinction_method',20X,'?'/
     9 '_refine_ls_extinction_expression',16X,'?'/
     1 '_refine_ls_extinction_coef',22X,'?'/)
C-----Absolute structure
      WRITE(*,153)
153   FORMAT(/' Is the space group acentric ? Y/N'/)
      READ(*,'(A1)')QS
      IF(QS.EQ.'Y'.OR.QS.EQ.'y')WRITE(15,154)
154   FORMAT('_refine_ls_abs_structure_Flack',18X,'?'/
     1 '_refine_ls_abs_structure_Rogers',17X,'?'//
     2 '_refine_ls_abs_structure_details'/';'/'......'/';'/)
      WRITE(15,155)
155   FORMAT('_refine_ls_number_reflns',24X,'?'/
     1 '_refine_ls_number_parameters',20X,'?'/
     2 '_refine_ls_number_restraints',20X,'?'/
     3 '_refine_ls_number_constraints',19X,'?'/
     4 '_refine_ls_R_factor_all',25X,'?'/
     5 '_refine_ls_R_factor_obs',25X,'?'/
     6 '_refine_ls_wR_factor_all',24X,'?'/
     7 '_refine_ls_wR_factor_obs',24X,'?'/
     8 '_refine_ls_goodness_of_fit_all',18X,'?'/
     9 '_refine_ls_goodness_of_fit_obs',18X,'?'/
     1 '_refine_ls_restrained_S_all',21X,'?'/
     2 '_refine_ls_restrained_S_obs',21X,'?'/
     3 '_refine_ls_shift/esd_max',24X,'?'/
     4 '_refine_ls_shift/esd_mean',23X,'?'/
     5 '_refine_diff_density_max',24X,'?'/
     6 '_refine_diff_density_min',24X,'?'/
     7 '_refine_diff_density_rms',24X,'?'/)
C-----Print intramolecular contacts less than 3.0 A
      WRITE(*,142)
142   FORMAT(/' Do you want contacts involving hydrogens ? Y/N'/)
      READ(*,'(A1)')QS
      WRITE(15,128)
128   FORMAT('loop_'/'_geom_contact_atom_site_label_1'/
     1 '_geom_contact_atom_site_label_2'/'_geom_contact_distance'/
     2 '#'/'#',3X,'This is the complete list of first-neighbour ',
     3 'intramolecular distances')
      IF(QS.EQ.'N'.OR.QS.EQ.'n')THEN
      WRITE(15,144)
144   FORMAT('#',3X,'less than 3.0 Angstrom for non-H atoms.')
      ELSE
      WRITE(15,143)
143   FORMAT('#',3X,'less than 3.0 Angstrom.')
      ENDIF
      WRITE(15,145)
145   FORMAT('#'/'#',5X,'lab1',4X,'lab2',8X,'distance'/)
      NN=10
25    READ(13,'(10A1)')DUM
      CALL MINUMA1(NN,DUM)
      DO 26 J=1,NN
      IF(DUM(J).NE.STR6(J))GO TO 25
26    CONTINUE
      DO 27 I=1,4
27    READ(13,'(10A1)')DUM
28    READ(13,'(4A1)')(DUM(K),K=1,4)
      NN=4
      CALL MINUMA1(NN,DUM)
      DO 29 J=1,NN
      IF(DUM(J).NE.STR2(J))GO TO 30
29    CONTINUE
      GO TO 31
30    BACKSPACE(13)
      READ(13,129)ATM1,ATM2,DD,ISDD
129   FORMAT(1X,4A1,3X,4A1,5X,F6.4,1X,I4)
      IF(DD.GT.3.0)GO TO 28
      ISDD=(ISDD+5)/10
      IF(QS.EQ.'N'.OR.QS.EQ.'n'.AND.(ATM1(1).EQ.'H'.OR.ATM2(1).EQ.'H'))
     1 GO TO 28
      IF(ISDD.LT.10)THEN
      WRITE(15,126)ATM1,ATM2,DD,ISDD
126   FORMAT(6X,4A1,4X,4A1,8X,F5.3,'(',I1,')')
      ELSEIF(ISDD.GE.10.AND.ISDD.LT.100)THEN
      WRITE(15,130)ATM1,ATM2,DD,ISDD
130   FORMAT(6X,4A1,4X,4A1,8X,F5.3,'(',I2,')')
      ELSEIF(ISDD.GE.100)THEN
      WRITE(15,148)ATM1,ATM2,DD,ISDD
148   FORMAT(6X,4A1,4X,4A1,8X,F5.3,'(',I3,')')
      ENDIF
      GO TO 28
31    CONTINUE
C-----Hydrogen bonds
      CALL HYDRCIF
      STOP
      END
 
      SUBROUTINE INTERIO
      CHARACTER*14 FILIN,FILOUT
      WRITE(*,100)
100   FORMAT(/' Key in the name of the input file'/)
      READ(*,'(A14)')FILIN
      WRITE(*,101)
101   FORMAT(/' Key in the name of the output file'/)
      READ(*,'(A14)')FILOUT
      OPEN(UNIT=13,FILE=FILIN,FORM='FORMATTED')
      REWIND(UNIT=13)
      OPEN(UNIT=15,FILE=FILOUT,FORM='FORMATTED')
      REWIND(UNIT=15)
      RETURN
      END
 
      SUBROUTINE MINUMA1(NN,STR)
C-----This routine transforms the lower case characters into upper
C-----case characters in a string of NN characters
      CHARACTER*1 MINU(26),MAIU(26),STR(NN)
      COMMON/GRP3/MINU
     1      /GRP4/MAIU
      DO 2 I=1,NN
      DO 1 J=1,26
      IF(STR(I).NE.MINU(J))GO TO 1
      STR(I)=MAIU(J)
      GO TO 2
1     CONTINUE
2     CONTINUE
      RETURN
      END
 
      SUBROUTINE TABCOOR(I,RR1,KDC,ISA,ATM,X,ISX,UE,ISE,STR4,TYP,STR5,
     1 ABH)
C-----Print the Table of the atomic coordinates
      CHARACTER*1 ATM(4),ABH(4),TYP(2)
      CHARACTER*5 STR4
      CHARACTER*4 STR5
      DIMENSION X(3),ISX(3),ISA(200,3)
      IF(KDC.EQ.1) THEN
      CALL TAB1(I,RR1,ISA,ATM,X,ISX,UE,ISE,STR4,TYP,STR5,ABH)
      RETURN
      ELSEIF(KDC.EQ.2) THEN
      CALL TAB2(I,RR1,ISA,ATM,X,ISX,UE,ISE,STR4,TYP,STR5,ABH)
      RETURN
      ELSEIF(KDC.EQ.3) THEN
      CALL TAB3(I,RR1,ISA,ATM,X,ISX,UE,ISE,STR4,TYP,STR5,ABH)
      RETURN
      ENDIF
      CALL TAB0(I,RR1,ISA,ATM,X,ISX,UE,ISE,STR4,TYP,STR5,ABH)
      RETURN
      END
 
      SUBROUTINE TAB0(I,RR1,ISA,ATM,X,ISX,UE,ISE,STR4,TYP,STR5,ABH)
C-----Print the Table of the atomic coordinates
      CHARACTER*1 ATM(4),ABH(4),TYP(2)
      CHARACTER*5 STR4
      CHARACTER*4 STR5
      DIMENSION X(3),ISX(3),ISA(200,3)
C-----Sigma(x)<10      sigma(y)<10     sigma(z)<10
      IF(ISA(I,1).LT.10.AND.ISA(I,2).LT.10.AND.ISA(I,3).LT.10) THEN
      WRITE(15,100)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
100   FORMAT(1X,4A1,1X,3(1X,F8.5,'(',I1,')'),1X,F6.4,'(',I2,')',1X,A5,
     1 1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C-----Sigma(x)>10<100      sigma(y)>10<100     sigma(z)>10<100
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).GE.10.AND.
     1 ISA(I,2).LT.100.AND.ISA(I,3).GE.10.AND.ISA(I,3).LT.100) THEN
      WRITE(15,101)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
101   FORMAT(1X,4A1,1X,3(1X,F7.4,'(',I1,')',1X),1X,F6.4,'(',I2,')',1X,
     1 A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C-----Sigma(x)<10      sigma(y)>10<100     sigma(z)>10<100
      ELSEIF(ISA(I,1).LT.10.AND.ISA(I,2).GE.10.AND.ISA(I,2).LT.100.
     1 AND.ISA(I,3).GE.10.AND.ISA(I,3).LT.100) THEN
      WRITE(15,102)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
102   FORMAT(1X,4A1,2X,F8.5,'(',I1,')',2(1X,F7.4,'(',I1,')',1X),
     1 1X,F6.4,'(',I2,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C-----Sigma(x)>10<100      sigma(y)<10     sigma(z)>10<100
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).LT.10.
     1 AND.ISA(I,3).GE.10.AND.ISA(I,3).LT.100) THEN
      WRITE(15,103)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
103   FORMAT(1X,4A1,2X,F7.4,'(',I1,')',2X,F8.5,'(',I1,')',1X,
     1 F7.4,'(',I1,')',2X,F6.4,'(',I2,')',1X,A5,1X,2A1,1X,A4,1X,4A1,
     2 1X,F5.2)
      GO TO 1
C-----Sigma(x)>10<100      sigma(y)>10<100     sigma(z)<10
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).GE.10.
     1 AND.ISA(I,2).LT.100.AND.ISA(I,3).LT.10) THEN
      WRITE(15,104)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
104   FORMAT(1X,4A1,1X,2(1X,F7.4,'(',I1,')',1X),1X,F8.5,'(',I1,')',
     1 1X,F6.4,'(',I2,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C-----Sigma(x)>10<100      sigma(y)<10     sigma(z)<10
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).LT.10.
     1 AND.ISA(I,3).LT.10) THEN
      WRITE(15,105)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
105   FORMAT(1X,4A1,2X,F7.4,'(',I1,')',1X ,2(1X,F8.5,'(',I1,')'),
     1 1X,F6.4,'(',I2,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C-----Sigma(x)<10      sigma(y)>10<100     sigma(z)<10
      ELSEIF(ISA(I,1).LT.10.AND.ISA(I,2).GE.10.AND.ISA(I,2).LT.100.
     1 AND.ISA(I,3).LT.10) THEN
      WRITE(15,106)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
106   FORMAT(1X,4A1,2X,F8.5,'(',I1,')',1X,F7.4,'(',I1,')',2X,
     1 F8.5,'(',I1,')',1X,F6.4,'(',I2,')',1X,A5,1X,2A1,1X,A4,1X,4A1,
     2 1X,F5.2)
      GO TO 1
C-----Sigma(x)<10      sigma(y)<10     sigma(z)>10<100
      ELSEIF(ISA(I,1).LT.10.AND.ISA(I,2).LT.10.AND.ISA(I,3).GE.10.
     1 AND.ISA(I,3).LT.100) THEN
      WRITE(15,107)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
107   FORMAT(1X,4A1,1X,2(1X,F8.5,'(',I1,')'),1X,F7.4,'(',I1,')',2X,
     1 F6.4,'(',I2,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>100<1000     sigma(y)>100<1000    sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.100.
     1 AND.ISA(I,2).LT.1000.AND.ISA(I,3).GE.100.AND.ISA(I,3).LT.1000)
     2 THEN
      WRITE(15,109)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
109   FORMAT(1X,4A1,1X,3(1X,F7.4,'(',I2,')'),1X,F6.4,'(',I2,')',1X,A5,
     1 1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C-----Sigma(x)>100<1000     sigma(y)>10<100    sigma(z)>10<100
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.10.
     1 AND.ISA(I,2).LT.100.AND.ISA(I,3).GE.10.AND.ISA(I,3).LT.100)THEN
      WRITE(15,110)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
110   FORMAT(1X,4A1,2X,F7.4,'(',I2,')',2(1X,F7.4,'(',I1,')',1X),
     1 1X,F6.4,'(',I2,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C-----Sigma(x)>10<100     sigma(y)>100<1000    sigma(z)>10<100
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).GE.100.AND
     1 .ISA(I,2).LT.1000.AND.ISA(I,3).GE.10.AND.ISA(I,3).LT.100) THEN
      WRITE(15,111)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
111   FORMAT(1X,4A1,2X,F7.4,'(',I1,')',2X,F7.4,'(',I2,')',1X,F7.4,'(',
     1 I1,')',2X,F6.4,'(',I2,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C-----Sigma(x)>10<100     sigma(y)>10<100    sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).GE.10.AND
     1 .ISA(I,2).LT.100.AND.ISA(I,3).GE.100.AND.ISA(I,3).LT.1000)THEN
      WRITE(15,112)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
112   FORMAT(1X,4A1,1X,2(1X,F7.4,'(',I1,')',1X),1X,F7.4,'(',I2,')',
     1 1X,F6.4,'(',I2,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C-----Sigma(x)>100<1000     sigma(y)>100<1000    sigma(z)>10<100
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.100.
     1 AND.ISA(I,2).LT.1000.AND.ISA(I,3).GE.10.AND.ISA(I,3).LT.100)
     1 THEN
      WRITE(15,113)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
113   FORMAT(1X,4A1,1X,2(1X,F7.4,'(',I2,')'),1X,F7.4,'(',I1,')',2X,
     1 F6.4,'(',I2,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C-----Sigma(x)>100<1000     sigma(y)>10<100    sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.10.
     1 AND.ISA(I,2).LT.100.AND.ISA(I,3).GE.100.AND.ISA(I,1).LT.1000)
     1 THEN
      WRITE(15,114)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
114   FORMAT(1X,4A1,2X,F7.4,'(',I2,')',1X,F7.4,'(',I1,')',2X,
     1 F7.4,'(',I2,')',1X,F6.4,'(',I2,')',1X,A5,1X,2A1,1X,A4,1X,4A1,
     2 1X,F5.2)
      GO TO 1
C-----Sigma(x)>10<100     sigma(y)>100<1000    sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).GE.100.
     1 AND.ISA(I,2).LT.1000.AND.ISA(I,3).GE.100.AND.ISA(I,3).LT.1000)
     1 THEN
      WRITE(15,115)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
115   FORMAT(1X,4A1,2X,F7.4,'(',I1,')',1X,2(1X,F7.4,'(',I2,')'),
     1 1X,F6.4,'(',I2,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C-----Sigma(x)>1000     sigma(y)>100<1000   sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.1000.AND.ISA(I,2).GE.100.AND.ISA(I,2).LT.1000.
     1 AND.ISA(I,3).GE.100.AND.ISA(I,3).LT.1000) THEN
      WRITE(15,156)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
156   FORMAT(1X,4A1,2X,F6.3,'(',I2,')',1X,2(1X,F7.4,'(',I2,')'),1X,
     1 F6.4,'(',I2,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C-----Sigma(x)>100<1000     sigma(y)>1000   sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.1000.
     1 AND.ISA(I,3).GE.100.AND.ISA(I,3).LT.1000) THEN
      WRITE(15,157)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
157   FORMAT(1X,4A1,2X,F7.4,'(',I2,')',1X,F6.3,'(',I2,')',2X,F7.4,'(',
     1 I2,')',1X,F6.4,'(',I2,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C-----Sigma(x)>100<1000     sigma(y)>100<1000   sigma(z)>1000
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.100.
     1 AND.ISA(I,2).LT.1000.AND.ISA(I,3).GE.1000) THEN
      WRITE(15,158)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
158   FORMAT(1X,4A1,1X,2(1X,F7.4,'(',I2,')'),1X,F6.3,'(',I2,')',2X,
     1 F6.4,'(',I2,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C-----Sigma(x)>1000     sigma(y)>1000   sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.1000.AND.ISA(I,2).GE.1000.AND.ISA(I,3).GE.100.
     1 AND.ISA(I,3).LT.1000) THEN
      WRITE(15,159)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
159   FORMAT(1X,4A1,1X,2(1X,F6.3,'(',I2,')',1X),1X,F7.4,'(',I2,')',1X,
     1 F6.4,'(',I2,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C-----Sigma(x)>1000     sigma(y)>100<1000   sigma(z)>1000
      ELSEIF(ISA(I,1).GE.1000.AND.ISA(I,2).GE.100.AND.ISA(I,2).LT.1000.
     1 AND.ISA(I,3).GE.1000) THEN
      WRITE(15,160)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
160   FORMAT(1X,4A1,2X,F6.3,'(',I2,')',2X,F7.4,'(',I2,')',1X,F6.3,'(',
     1 I2,')',2X,F6.4,'(',I2,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C-----Sigma(x)>100<1000     sigma(y)>1000   sigma(z)>1000
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.1000.
     1 AND.ISA(I,3).GE.1000) THEN
      WRITE(15,161)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
161   FORMAT(1X,4A1,2X,F7.4,'(',I2,')',2(1X,F6.3,'(',I2,')',1X),1X,
     1 F6.4,'(',I2,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C-----Sigma(x)>1000     sigma(y)>1000   sigma(z)>1000
      ELSEIF(ISA(I,1).GE.1000.AND.ISA(I,2).GE.1000.AND.ISA(I,3).GE.1000)
     1 THEN
      WRITE(15,162)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
162   FORMAT(1X,4A1,1X,3(1X,F6.3,'(',I2,')',1X),1X,F6.4,'(',I2,')',1X,
     1 A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      ENDIF
1     RETURN
      END
 
      SUBROUTINE TAB1(I,RR1,ISA,ATM,X,ISX,UE,ISE,STR4,TYP,STR5,ABH)
C-----Print the Table of the atomic coordinates
      CHARACTER*1 ATM(4),ABH(4),TYP(2)
      CHARACTER*5 STR4
      CHARACTER*4 STR5
      DIMENSION X(3),ISX(3),ISA(200,3)
C*----Sigma(x)<10      sigma(y)<10     sigma(z)<10
      IF(ISA(I,1).LT.10.AND.ISA(I,2).LT.10.AND.ISA(I,3).LT.10) THEN
      WRITE(15,116)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
116   FORMAT(1X,4A1,1X,3(1X,F8.5,'(',I1,')'),1X,F5.3,'(',I2,')',2X,A5,
     1 1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>10<100      sigma(y)>10<100     sigma(z)>10<100
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).GE.10.AND.
     1 ISA(I,2).LT.100.AND.ISA(I,3).GE.10.AND.ISA(I,3).LT.100) THEN
      WRITE(15,117)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
117   FORMAT(1X,4A1,1X,3(1X,F7.4,'(',I1,')',1X),1X,F5.3,'(',I2,')',2X,
     1 A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)<10      sigma(y)>10<100     sigma(z)>10<100
      ELSEIF(ISA(I,1).LT.10.AND.ISA(I,2).GE.10.AND.ISA(I,2).LT.100.
     1 AND.ISA(I,3).GE.10.AND.ISA(I,3).LT.100) THEN
      WRITE(15,118)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
118   FORMAT(1X,4A1,2X,F8.5,'(',I1,')',2(1X,F7.4,'(',I1,')',1X),
     1 1X,F5.3,'(',I2,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>10<100      sigma(y)<10     sigma(z)>10<100
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).LT.10.
     1 AND.ISA(I,3).GE.10.AND.ISA(I,3).LT.100) THEN
      WRITE(15,119)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
119   FORMAT(1X,4A1,2X,F7.4,'(',I1,')',2X,F8.5,'(',I1,')',1X,
     1 F7.4,'(',I1,')',2X,F5.3,'(',I2,')',2X,A5,1X,2A1,1X,A4,1X,4A1,
     2 1X,F5.2)
      GO TO 1
C*----Sigma(x)>10<100      sigma(y)>10<100     sigma(z)<10
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).GE.10.
     1 AND.ISA(I,2).LT.100.AND.ISA(I,3).LT.10) THEN
      WRITE(15,120)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
120   FORMAT(1X,4A1,1X,2(1X,F7.4,'(',I1,')',1X),1X,F8.5,'(',I1,')',
     1 1X,F5.3,'(',I2,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>10<100      sigma(y)<10     sigma(z)<10
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).LT.10.
     1 AND.ISA(I,3).LT.10) THEN
      WRITE(15,121)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
121   FORMAT(1X,4A1,2X,F7.4,'(',I1,')',1X ,2(1X,F8.5,'(',I1,')'),
     1 1X,F5.3,'(',I2,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)<10      sigma(y)>10<100     sigma(z)<10
      ELSEIF(ISA(I,1).LT.10.AND.ISA(I,2).GE.10.AND.ISA(I,2).LT.100.
     1 AND.ISA(I,3).LT.10) THEN
      WRITE(15,122)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
122   FORMAT(1X,4A1,2X,F8.5,'(',I1,')',1X,F7.4,'(',I1,')',2X,
     1 F8.5,'(',I1,')',1X,F5.3,'(',I2,')',2X,A5,1X,2A1,1X,A4,1X,4A1,
     2 1X,F5.2)
      GO TO 1
C*----Sigma(x)<10      sigma(y)<10     sigma(z)>10<100
      ELSEIF(ISA(I,1).LT.10.AND.ISA(I,2).LT.10.AND.ISA(I,3).GE.10.
     1 AND.ISA(I,3).LT.100) THEN
      WRITE(15,123)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
123   FORMAT(1X,4A1,1X,2(1X,F8.5,'(',I1,')'),1X,F7.4,'(',I1,')',2X,
     1 F5.3,'(',I2,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>100<1000   sigma(y)>100<1000    sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.100.
     1 AND.ISA(I,2).LT.1000.AND.ISA(I,3).GE.100.AND.ISA(I,3).LT.1000)
     2 THEN
      WRITE(15,125)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
125   FORMAT(1X,4A1,1X,3(1X,F7.4,'(',I2,')'),1X,F5.3,'(',I2,')',2X,A5,
     1 1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>100<1000   sigma(y)>10<100    sigma(z)>10<100
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.10.
     1 AND.ISA(I,2).LT.100.AND.ISA(I,3).GE.10.AND.ISA(I,3).LT.100)THEN
      WRITE(15,126)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
126   FORMAT(1X,4A1,2X,F7.4,'(',I2,')',2(1X,F7.4,'(',I1,')',1X),
     1 1X,F5.3,'(',I2,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>10<100     sigma(y)>100<1000    sigma(z)>10<100
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).GE.100.
     1 AND.ISA(I,2).LT.1000.AND.ISA(I,3).GE.10.AND.ISA(I,3).LT.100)THEN
      WRITE(15,127)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
127   FORMAT(1X,4A1,2X,F7.4,'(',I1,')',2X,F7.4,'(',I2,')',1X,F7.4,'(',
     1 I1,')',2X,F5.3,'(',I2,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>10<100     sigma(y)>10<100    sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).GE.10.AND.
     1 ISA(I,2).LT.100.AND.ISA(I,3).GE.100.AND.ISA(I,3).LT.1000) THEN
      WRITE(15,128)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
128   FORMAT(1X,4A1,1X,2(1X,F7.4,'(',I1,')',1X),1X,F7.4,'(',I2,')',
     1 1X,F5.3,'(',I2,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>100<1000   sigma(y)>100<1000   sigma(z)>10<100
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.100.
     1 AND.ISA(I,2).LT.1000.AND.ISA(I,3).GE.10.AND.ISA(I,3).LT.100)THEN
      WRITE(15,129)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
129   FORMAT(1X,4A1,1X,2(1X,F7.4,'(',I2,')'),1X,F7.4,'(',I1,')',2X,
     1 F5.3,'(',I2,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>100<1000     sigma(y)>10<100    sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.10.
     1 AND.ISA(I,2).LT.100.AND.ISA(I,3).GE.100.AND.ISA(I,3).LT.1000)THEN
      WRITE(15,130)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
130   FORMAT(1X,4A1,2X,F7.4,'(',I2,')',1X,F7.4,'(',I1,')',2X,
     1 F7.4,'(',I2,')',1X,F5.3,'(',I2,')',2X,A5,1X,2A1,1X,A4,1X,4A1,
     2 1X,F5.2)
      GO TO 1
C*----Sigma(x)>10<100     sigma(y)>100<1000    sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).GE.100.
     1 AND.ISA(I,2).LT.1000.AND.ISA(I,3).GE.100.AND.ISA(I,3).LT.1000)
     2 THEN
      WRITE(15,131)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
131   FORMAT(1X,4A1,2X,F7.4,'(',I1,')',1X,2(1X,F7.4,'(',I2,')'),
     1 1X,F5.3,'(',I2,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>1000     sigma(y)>100<1000   sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.1000.AND.ISA(I,2).GE.100.AND.ISA(I,2).LT.1000.
     1 AND.ISA(I,3).GE.100.AND.ISA(I,3).LT.1000) THEN
      WRITE(15,163)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
163   FORMAT(1X,4A1,2X,F6.3,'(',I2,')',1X,2(1X,F7.4,'(',I2,')'),1X,
     1 F5.3,'(',I2,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>100<1000     sigma(y)>1000   sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.1000.
     1 AND.ISA(I,3).GE.100.AND.ISA(I,3).LT.1000) THEN
      WRITE(15,164)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
164   FORMAT(1X,4A1,2X,F7.4,'(',I2,')',1X,F6.3,'(',I2,')',2X,F7.4,'(',
     1 I2,')',1X,F5.3,'(',I2,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>100<1000     sigma(y)>100<1000   sigma(z)>1000
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.100.
     1 AND.ISA(I,2).LT.1000.AND.ISA(I,3).GE.1000) THEN
      WRITE(15,165)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
165   FORMAT(1X,4A1,1X,2(1X,F7.4,'(',I2,')'),1X,F6.3,'(',I2,')',2X,
     1 F5.3,'(',I2,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>1000     sigma(y)>1000   sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.1000.AND.ISA(I,2).GE.1000.AND.ISA(I,3).GE.100.
     1 AND.ISA(I,3).LT.1000) THEN
      WRITE(15,166)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
166   FORMAT(1X,4A1,1X,2(1X,F6.3,'(',I2,')',1X),1X,F7.4,'(',I2,')',1X,
     1 F5.3,'(',I2,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>1000     sigma(y)>100<1000   sigma(z)>1000
      ELSEIF(ISA(I,1).GE.1000.AND.ISA(I,2).GE.100.AND.ISA(I,2).LT.1000.
     1 AND.ISA(I,3).GE.1000) THEN
      WRITE(15,167)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
167   FORMAT(1X,4A1,2X,F6.3,'(',I2,')',2X,F7.4,'(',I2,')',1X,F6.3,'(',
     1 I2,')',2X,F5.3,'(',I2,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>100<1000     sigma(y)>1000   sigma(z)>1000
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.1000.
     1 AND.ISA(I,3).GE.1000) THEN
      WRITE(15,168)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
168   FORMAT(1X,4A1,2X,F7.4,'(',I2,')',2(1X,F6.3,'(',I2,')',1X),1X,
     1 F5.3,'(',I2,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>1000     sigma(y)>1000   sigma(z)>1000
      ELSEIF(ISA(I,1).GE.1000.AND.ISA(I,2).GE.1000.AND.ISA(I,3).GE.1000)
     1 THEN
      WRITE(15,169)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
169   FORMAT(1X,4A1,1X,3(1X,F6.3,'(',I2,')',1X),1X,F5.3,'(',I2,')',2X,
     1 A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      ENDIF
1     RETURN
      END
 
      SUBROUTINE TAB2(I,RR1,ISA,ATM,X,ISX,UE,ISE,STR4,TYP,STR5,ABH)
C-----Print the Table of the atomic coordinates
      CHARACTER*1 ATM(4),ABH(4),TYP(2)
      CHARACTER*5 STR4
      CHARACTER*4 STR5
      DIMENSION X(3),ISX(3),ISA(200,3)
C**---Sigma(x)<10      sigma(y)<10     sigma(z)<10
      IF(ISA(I,1).LT.10.AND.ISA(I,2).LT.10.AND.ISA(I,3).LT.10) THEN
      WRITE(15,132)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
132   FORMAT(1X,4A1,1X,3(1X,F8.5,'(',I1,')'),1X,F6.4,'(',I1,')',2X,A5,
     1 1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C**---Sigma(x)>10<100      sigma(y)>10<100     sigma(z)>10<100
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).GE.10.AND.
     1 ISA(I,2).LT.100.AND.ISA(I,3).GE.10.AND.ISA(I,3).LT.100) THEN
      WRITE(15,133)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
133   FORMAT(1X,4A1,1X,3(1X,F7.4,'(',I1,')',1X),1X,F6.4,'(',I1,')',2X,
     1 A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C**---Sigma(x)<10      sigma(y)>10<100     sigma(z)>10<100
      ELSEIF(ISA(I,1).LT.10.AND.ISA(I,2).GE.10.AND.ISA(I,2).LT.100.
     1 AND.ISA(I,3).GE.10.AND.ISA(I,3).LT.100) THEN
      WRITE(15,134)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
134   FORMAT(1X,4A1,2X,F8.5,'(',I1,')',2(1X,F7.4,'(',I1,')',1X),
     1 1X,F6.4,'(',I1,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C**---Sigma(x)>10<100      sigma(y)<10     sigma(z)>10<100
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).LT.10.
     1 AND.ISA(I,3).GE.10.AND.ISA(I,3).LT.100) THEN
      WRITE(15,135)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
135   FORMAT(1X,4A1,2X,F7.4,'(',I1,')',2X,F8.5,'(',I1,')',1X,
     1 F7.4,'(',I1,')',2X,F6.4,'(',I1,')',2X,A5,1X,2A1,1X,A4,1X,4A1,
     2 1X,F5.2)
      GO TO 1
C**---Sigma(x)>10<100      sigma(y)>10<100     sigma(z)<10
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).GE.10.
     1 AND.ISA(I,2).LT.100.AND.ISA(I,3).LT.10) THEN
      WRITE(15,136)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
136   FORMAT(1X,4A1,1X,2(1X,F7.4,'(',I1,')',1X),1X,F8.5,'(',I1,')',
     1 1X,F6.4,'(',I1,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C**---Sigma(x)>10<100      sigma(y)<10     sigma(z)<10
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).LT.10.
     1 AND.ISA(I,3).LT.10) THEN
      WRITE(15,137)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
137   FORMAT(1X,4A1,2X,F7.4,'(',I1,')',1X ,2(1X,F8.5,'(',I1,')'),
     1 1X,F6.4,'(',I1,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C**---Sigma(x)<10      sigma(y)>10<100     sigma(z)<10
      ELSEIF(ISA(I,1).LT.10.AND.ISA(I,2).GE.10.AND.ISA(I,2).LT.100.
     1 AND.ISA(I,3).LT.10) THEN
      WRITE(15,138)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
138   FORMAT(1X,4A1,2X,F8.5,'(',I1,')',1X,F7.4,'(',I1,')',2X,
     1 F8.5,'(',I1,')',1X,F6.4,'(',I1,')',2X,A5,1X,2A1,1X,A4,1X,4A1,
     2 1X,F5.2)
      GO TO 1
C**---Sigma(x)<10      sigma(y)<10     sigma(z)>10<100
      ELSEIF(ISA(I,1).LT.10.AND.ISA(I,2).LT.10.AND.ISA(I,3).GE.10.
     1 AND.ISA(I,3).LT.100) THEN
      WRITE(15,139)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
139   FORMAT(1X,4A1,1X,2(1X,F8.5,'(',I1,')'),1X,F7.4,'(',I1,')',2X,
     1 F6.4,'(',I1,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C**---Sigma(x)>100<1000    sigma(y)>100<1000    sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.100.
     1 AND.ISA(I,2).LT.1000.AND.ISA(I,3).GE.100.AND.ISA(I,3).LT.1000)
     2 THEN
      WRITE(15,140)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
140   FORMAT(1X,4A1,1X,3(1X,F7.4,'(',I2,')'),1X,F6.4,'(',I1,')',2X,A5,
     1 1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C**---Sigma(x)>100<1000     sigma(y)>10<100    sigma(z)>10<100
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.10.
     1 AND.ISA(I,2).LT.100.AND.ISA(I,3).GE.10.AND.ISA(I,3).LT.100)THEN
      WRITE(15,141)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
141   FORMAT(1X,4A1,2X,F7.4,'(',I2,')',2(1X,F7.4,'(',I1,')',1X),
     1 1X,F6.4,'(',I1,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C**---Sigma(x)>10<100     sigma(y)>100<1000    sigma(z)>10<100
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).GE.100.AND
     1 .ISA(I,2).LT.1000.AND.ISA(I,3).GE.10.AND.ISA(I,3).LT.100) THEN
      WRITE(15,142)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
142   FORMAT(1X,4A1,2X,F7.4,'(',I1,')',2X,F7.4,'(',I2,')',1X,F7.4,'(',
     1 I1,')',2X,F6.4,'(',I1,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C**---Sigma(x)>10<100     sigma(y)>10<100    sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).GE.10.AND
     1 .ISA(I,2).LT.100.AND.ISA(I,3).GE.100.AND.ISA(I,3).LT.1000)THEN
      WRITE(15,143)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
143   FORMAT(1X,4A1,1X,2(1X,F7.4,'(',I1,')',1X),1X,F7.4,'(',I2,')',
     1 1X,F6.4,'(',I1,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C**---Sigma(x)>100<1000    sigma(y)>100<1000    sigma(z)>10<100
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.100.
     1 AND.ISA(I,2).LT.1000.AND.ISA(I,3).GE.10.AND.ISA(I,3).LT.100)
     1 THEN
      WRITE(15,144)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
144   FORMAT(1X,4A1,1X,2(1X,F7.4,'(',I2,')'),1X,F7.4,'(',I1,')',2X,
     1 F6.4,'(',I1,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C**---Sigma(x)>100<1000   sigma(y)>10<100    sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.10.
     1 AND.ISA(I,2).LT.100.AND.ISA(I,3).GE.100.AND.ISA(I,3).LT.1000)
     1 THEN
      WRITE(15,145)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
145   FORMAT(1X,4A1,2X,F7.4,'(',I2,')',1X,F7.4,'(',I1,')',2X,
     1 F7.4,'(',I1,')',2X,F6.4,'(',I1,')',2X,A5,1X,2A1,1X,A4,1X,4A1,
     2 1X,F5.2)
      GO TO 1
C**---Sigma(x)>10<100     sigma(y)>100<1000    sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).GE.100.
     1 AND.ISA(I,2).LT.1000.AND.ISA(I,3).GE.100.AND.ISA(I,3).LT.1000)
     2 THEN
      WRITE(15,146)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
146   FORMAT(1X,4A1,2X,F7.4,'(',I1,')',1X,2(1X,F7.4,'(',I2,')'),
     1 1X,F6.4,'(',I1,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C**---Sigma(x)>1000     sigma(y)>100<1000   sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.1000.AND.ISA(I,2).GE.100.AND.ISA(I,2).LT.1000.
     1 AND.ISA(I,3).GE.100.AND.ISA(I,3).LT.1000) THEN
      WRITE(15,170)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
170   FORMAT(1X,4A1,2X,F6.3,'(',I2,')',1X,2(1X,F7.4,'(',I2,')'),1X,
     1 F6.4,'(',I1,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C**---Sigma(x)>100<1000     sigma(y)>1000   sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.1000.
     1 AND.ISA(I,3).GE.100.AND.ISA(I,3).LT.1000) THEN
      WRITE(15,171)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
171   FORMAT(1X,4A1,2X,F7.4,'(',I2,')',1X,F6.3,'(',I2,')',2X,F7.4,'(',
     1 I2,')',1X,F6.4,'(',I1,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C**---Sigma(x)>100<1000     sigma(y)>100<1000   sigma(z)>1000
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.100.
     1 AND.ISA(I,2).LT.1000.AND.ISA(I,3).GE.1000) THEN
      WRITE(15,172)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
172   FORMAT(1X,4A1,1X,2(1X,F7.4,'(',I2,')'),1X,F6.3,'(',I2,')',2X,
     1 F6.4,'(',I1,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C**---Sigma(x)>1000     sigma(y)>1000   sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.1000.AND.ISA(I,2).GE.1000.AND.ISA(I,3).GE.100.
     1 AND.ISA(I,3).LT.1000) THEN
      WRITE(15,173)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
173   FORMAT(1X,4A1,1X,2(1X,F6.3,'(',I2,')',1X),1X,F7.4,'(',I2,')',1X,
     1 F6.4,'(',I1,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C**---Sigma(x)>1000     sigma(y)>100<1000   sigma(z)>1000
      ELSEIF(ISA(I,1).GE.1000.AND.ISA(I,2).GE.100.AND.ISA(I,2).LT.1000.
     1 AND.ISA(I,3).GE.1000) THEN
      WRITE(15,174)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
174   FORMAT(1X,4A1,2X,F6.3,'(',I2,')',2X,F7.4,'(',I2,')',1X,F6.3,'(',
     1 I2,')',2X,F6.4,'(',I1,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C**---Sigma(x)>100<1000     sigma(y)>1000   sigma(z)>1000
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.1000.
     1 AND.ISA(I,3).GE.1000) THEN
      WRITE(15,175)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
175   FORMAT(1X,4A1,2X,F7.4,'(',I2,')',2(1X,F6.3,'(',I2,')',1X),1X,
     1 F6.4,'(',I1,')',2X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C**---Sigma(x)>1000     sigma(y)>1000   sigma(z)>1000
      ELSEIF(ISA(I,1).GE.1000.AND.ISA(I,2).GE.1000.AND.ISA(I,3).GE.1000)
     1 THEN
      WRITE(15,176)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
176   FORMAT(1X,4A1,1X,3(1X,F6.3,'(',I2,')',1X),1X,F6.4,'(',I1,')',2X,
     1 A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      ENDIF
1     RETURN
      END
 
      SUBROUTINE TAB3(I,RR1,ISA,ATM,X,ISX,UE,ISE,STR4,TYP,STR5,ABH)
C-----Print the Table of the atomic coordinates
      CHARACTER*1 ATM(4),ABH(4),TYP(2)
      CHARACTER*5 STR4
      CHARACTER*4 STR5
      DIMENSION X(3),ISX(3),ISA(200,3)
C*----Sigma(x)<10      sigma(y)<10     sigma(z)<10
      IF(ISA(I,1).LT.10.AND.ISA(I,2).LT.10.AND.ISA(I,3).LT.10) THEN
      WRITE(15,177)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
177   FORMAT(1X,4A1,1X,3(1X,F8.5,'(',I1,')'),1X,F5.3,'(',I3,')',1X,A5,
     1 1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>10<100      sigma(y)>10<100     sigma(z)>10<100
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).GE.10.AND.
     1 ISA(I,2).LT.100.AND.ISA(I,3).GE.10.AND.ISA(I,3).LT.100) THEN
      WRITE(15,178)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
178   FORMAT(1X,4A1,1X,3(1X,F7.4,'(',I1,')',1X),1X,F5.3,'(',I3,')',1X,
     1 A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)<10      sigma(y)>10<100     sigma(z)>10<100
      ELSEIF(ISA(I,1).LT.10.AND.ISA(I,2).GE.10.AND.ISA(I,2).LT.100.
     1 AND.ISA(I,3).GE.10.AND.ISA(I,3).LT.100) THEN
      WRITE(15,179)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
179   FORMAT(1X,4A1,2X,F8.5,'(',I1,')',2(1X,F7.4,'(',I1,')',1X),
     1 1X,F5.3,'(',I3,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>10<100      sigma(y)<10     sigma(z)>10<100
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).LT.10.
     1 AND.ISA(I,3).GE.10.AND.ISA(I,3).LT.100) THEN
      WRITE(15,180)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
180   FORMAT(1X,4A1,2X,F7.4,'(',I1,')',2X,F8.5,'(',I1,')',1X,
     1 F7.4,'(',I1,')',2X,F5.3,'(',I3,')',1X,A5,1X,2A1,1X,A4,1X,4A1,
     2 1X,F5.2)
      GO TO 1
C*----Sigma(x)>10<100      sigma(y)>10<100     sigma(z)<10
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).GE.10.
     1 AND.ISA(I,2).LT.100.AND.ISA(I,3).LT.10) THEN
      WRITE(15,181)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
181   FORMAT(1X,4A1,1X,2(1X,F7.4,'(',I1,')',1X),1X,F8.5,'(',I1,')',
     1 1X,F5.3,'(',I3,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>10<100      sigma(y)<10     sigma(z)<10
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).LT.10.
     1 AND.ISA(I,3).LT.10) THEN
      WRITE(15,182)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
182   FORMAT(1X,4A1,2X,F7.4,'(',I1,')',1X ,2(1X,F8.5,'(',I1,')'),
     1 1X,F5.3,'(',I3,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)<10      sigma(y)>10<100     sigma(z)<10
      ELSEIF(ISA(I,1).LT.10.AND.ISA(I,2).GE.10.AND.ISA(I,2).LT.100.
     1 AND.ISA(I,3).LT.10) THEN
      WRITE(15,183)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
183   FORMAT(1X,4A1,2X,F8.5,'(',I1,')',1X,F7.4,'(',I1,')',2X,
     1 F8.5,'(',I1,')',1X,F5.3,'(',I3,')',1X,A5,1X,2A1,1X,A4,1X,4A1,
     2 1X,F5.2)
      GO TO 1
C*----Sigma(x)<10      sigma(y)<10     sigma(z)>10<100
      ELSEIF(ISA(I,1).LT.10.AND.ISA(I,2).LT.10.AND.ISA(I,3).GE.10.
     1 AND.ISA(I,3).LT.100) THEN
      WRITE(15,184)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
184   FORMAT(1X,4A1,1X,2(1X,F8.5,'(',I1,')'),1X,F7.4,'(',I1,')',2X,
     1 F5.3,'(',I3,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>100<1000   sigma(y)>100<1000    sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.100.
     1 AND.ISA(I,2).LT.1000.AND.ISA(I,3).GE.100.AND.ISA(I,3).LT.1000)
     2 THEN
      WRITE(15,185)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
185   FORMAT(1X,4A1,1X,3(1X,F7.4,'(',I2,')'),1X,F5.3,'(',I3,')',1X,A5,
     1 1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>100<1000   sigma(y)>10<100    sigma(z)>10<100
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.10.
     1 AND.ISA(I,2).LT.100.AND.ISA(I,3).GE.10.AND.ISA(I,3).LT.100)THEN
      WRITE(15,186)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
186   FORMAT(1X,4A1,2X,F7.4,'(',I2,')',2(1X,F7.4,'(',I1,')',1X),
     1 1X,F5.3,'(',I3,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>10<100     sigma(y)>100<1000    sigma(z)>10<100
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).GE.100.
     1 AND.ISA(I,2).LT.1000.AND.ISA(I,3).GE.10.AND.ISA(I,3).LT.100)THEN
      WRITE(15,187)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
187   FORMAT(1X,4A1,2X,F7.4,'(',I1,')',2X,F7.4,'(',I2,')',1X,F7.4,'(',
     1 I1,')',2X,F5.3,'(',I3,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>10<100     sigma(y)>10<100    sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).GE.10.AND.
     1 ISA(I,2).LT.100.AND.ISA(I,3).GE.100.AND.ISA(I,3).LT.1000) THEN
      WRITE(15,188)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
188   FORMAT(1X,4A1,1X,2(1X,F7.4,'(',I1,')',1X),1X,F7.4,'(',I2,')',
     1 1X,F5.3,'(',I3,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>100<1000   sigma(y)>100<1000   sigma(z)>10<100
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.100.
     1 AND.ISA(I,2).LT.1000.AND.ISA(I,3).GE.10.AND.ISA(I,3).LT.100)THEN
      WRITE(15,189)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
189   FORMAT(1X,4A1,1X,2(1X,F7.4,'(',I2,')'),1X,F7.4,'(',I1,')',2X,
     1 F5.3,'(',I3,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>100<1000     sigma(y)>10<100    sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.10.
     1 AND.ISA(I,2).LT.100.AND.ISA(I,3).GE.100.AND.ISA(I,3).LT.1000)THEN
      WRITE(15,190)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
190   FORMAT(1X,4A1,2X,F7.4,'(',I2,')',1X,F7.4,'(',I1,')',2X,
     1 F7.4,'(',I2,')',1X,F5.3,'(',I3,')',1X,A5,1X,2A1,1X,A4,1X,4A1,
     2 1X,F5.2)
      GO TO 1
C*----Sigma(x)>10<100     sigma(y)>100<1000    sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.10.AND.ISA(I,1).LT.100.AND.ISA(I,2).GE.100.
     1 AND.ISA(I,2).LT.1000.AND.ISA(I,3).GE.100.AND.ISA(I,3).LT.1000)
     2 THEN
      WRITE(15,191)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
191   FORMAT(1X,4A1,2X,F7.4,'(',I1,')',1X,2(1X,F7.4,'(',I2,')'),
     1 1X,F5.3,'(',I3,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>1000     sigma(y)>100<1000   sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.1000.AND.ISA(I,2).GE.100.AND.ISA(I,2).LT.1000.
     1 AND.ISA(I,3).GE.100.AND.ISA(I,3).LT.1000) THEN
      WRITE(15,192)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
192   FORMAT(1X,4A1,2X,F6.3,'(',I2,')',1X,2(1X,F7.4,'(',I2,')'),1X,
     1 F5.3,'(',I3,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>100<1000     sigma(y)>1000   sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.1000.
     1 AND.ISA(I,3).GE.100.AND.ISA(I,3).LT.1000) THEN
      WRITE(15,193)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
193   FORMAT(1X,4A1,2X,F7.4,'(',I2,')',1X,F6.3,'(',I2,')',2X,F7.4,'(',
     1 I2,')',1X,F5.3,'(',I3,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>100<1000     sigma(y)>100<1000   sigma(z)>1000
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.100.
     1 AND.ISA(I,2).LT.1000.AND.ISA(I,3).GE.1000) THEN
      WRITE(15,194)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
194   FORMAT(1X,4A1,1X,2(1X,F7.4,'(',I2,')'),1X,F6.3,'(',I2,')',2X,
     1 F5.3,'(',I3,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>1000     sigma(y)>1000   sigma(z)>100<1000
      ELSEIF(ISA(I,1).GE.1000.AND.ISA(I,2).GE.1000.AND.ISA(I,3).GE.100.
     1 AND.ISA(I,3).LT.1000) THEN
      WRITE(15,195)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
195   FORMAT(1X,4A1,1X,2(1X,F6.3,'(',I2,')',1X),1X,F7.4,'(',I2,')',1X,
     1 F5.3,'(',I3,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>1000     sigma(y)>100<1000   sigma(z)>1000
      ELSEIF(ISA(I,1).GE.1000.AND.ISA(I,2).GE.100.AND.ISA(I,2).LT.1000.
     1 AND.ISA(I,3).GE.1000) THEN
      WRITE(15,196)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
196   FORMAT(1X,4A1,2X,F6.3,'(',I2,')',2X,F7.4,'(',I2,')',1X,F6.3,'(',
     1 I2,')',2X,F5.3,'(',I3,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>100<1000     sigma(y)>1000   sigma(z)>1000
      ELSEIF(ISA(I,1).GE.100.AND.ISA(I,1).LT.1000.AND.ISA(I,2).GE.1000.
     1 AND.ISA(I,3).GE.1000) THEN
      WRITE(15,197)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
197   FORMAT(1X,4A1,2X,F7.4,'(',I2,')',2(1X,F6.3,'(',I2,')',1X),1X,
     1 F5.3,'(',I3,')',1X,A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      GO TO 1
C*----Sigma(x)>1000     sigma(y)>1000   sigma(z)>1000
      ELSEIF(ISA(I,1).GE.1000.AND.ISA(I,2).GE.1000.AND.ISA(I,3).GE.1000)
     1 THEN
      WRITE(15,198)(ATM(K),K=1,4),(X(K),ISX(K),K=1,3),UE,ISE,STR4,TYP,
     1 STR5,(ABH(K),K=1,4),RR1
198   FORMAT(1X,4A1,1X,3(1X,F6.3,'(',I2,')',1X),1X,F5.3,'(',I3,')',1X,
     1 A5,1X,2A1,1X,A4,1X,4A1,1X,F5.2)
      ENDIF
1     RETURN
      END
 
      SUBROUTINE WRTU(AAAA,UU,IUS)
      CHARACTER*1 AAAA(4)
      DIMENSION UU(6),IUS(6)
C-----One sigma(U) > 100
      IF(IUS(1).GE.100.OR.IUS(2).GE.100.OR.IUS(3).GE.100.OR.
     1 IUS(4).GE.100.OR.IUS(5).GE.100.OR.IUS(6).GE.100)THEN
      DO 1 L=1,6
1     IUS(L)=(IUS(L)+5)/10
      WRITE(15,164)AAAA,(UU(L),IUS(L),L=1,6)
164   FORMAT(4A1,1X,6(F6.3,'(',I2,')',2X))
      GO TO 2
      ENDIF
C-----sU11<10, sU22<10, sU33<10, sU12<10, sU13<10, sU23<10
      IF(IUS(1).LT.10.AND.IUS(2).LT.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).LT.10.AND.IUS(6).LT.10)THEN
      WRITE(15,100)AAAA,(UU(L),IUS(L),L=1,6)
100   FORMAT(4A1,1X,6(F7.4,'(',I1,')',2X))
C-----sU11>10, sU22>10, sU33>10, sU12>10, sU13>10, sU23>10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).GE.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).GE.10.AND.IUS(6).GE.10)THEN
      WRITE(15,101)AAAA,(UU(L),IUS(L),L=1,6)
101   FORMAT(4A1,1X,6(F7.4,'(',I2,')',1X))
C-----sU11<10, sU22>10, sU33>10, sU12>10, sU13>10, sU23>10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).GE.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).GE.10.AND.IUS(6).GE.10)THEN
      WRITE(15,102)AAAA,(UU(L),IUS(L),L=1,6)
102   FORMAT(4A1,1X,F7.4,'(',I1,')',2X,5(F7.4,'(',I2,')',1X))
C-----sU11>10, sU22<10, sU33>10, sU12>10, sU13>10, sU23>10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).LT.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).GE.10.AND.IUS(6).GE.10)THEN
      WRITE(15,103)AAAA,(UU(L),IUS(L),L=1,6)
103   FORMAT(4A1,1X,F7.4,'(',I2,')',1X,F7.4,'(',I1,')',2X,
     1 4(F7.4,'(',I2,')',1X))
C-----sU11>10, sU22>10, sU33<10, sU12>10, sU13>10, sU23>10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).GE.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).GE.10.AND.IUS(6).GE.10)THEN
      WRITE(15,104)AAAA,(UU(L),IUS(L),L=1,6)
104   FORMAT(4A1,1X,2(F7.4,'(',I2,')',1X),F7.4,'(',I1,')',2X,
     1 3(F7.4,'(',I2,')',1X))
C-----sU11>10, sU22>10, sU33>10, sU12<10, sU13>10, sU23>10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).GE.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).GE.10.AND.IUS(6).GE.10)THEN
      WRITE(15,105)AAAA,(UU(L),IUS(L),L=1,6)
105   FORMAT(4A1,1X,3(F7.4,'(',I2,')',1X),F7.4,'(',I1,')',2X,
     1 2(F7.4,'(',I2,')',1X))
C-----sU11>10, sU22>10, sU33>10, sU12>10, sU13<10, sU23>10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).GE.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).LT.10.AND.IUS(6).GE.10)THEN
      WRITE(15,106)AAAA,(UU(L),IUS(L),L=1,6)
106   FORMAT(4A1,1X,4(F7.4,'(',I2,')',1X),F7.4,'(',I1,')',2X,
     1 F7.4,'(',I2,')')
C-----sU11>10, sU22>10, sU33>10, sU12>10, sU13>10, sU23<10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).GE.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).GE.10.AND.IUS(6).LT.10)THEN
      WRITE(15,107)AAAA,(UU(L),IUS(L),L=1,6)
107   FORMAT(4A1,1X,5(F7.4,'(',I2,')',1X),F7.4,'(',I1,')')
C-----sU11<10, sU22<10, sU33>10, sU12>10, sU13>10, sU23>10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).LT.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).GE.10.AND.IUS(6).GE.10)THEN
      WRITE(15,108)AAAA,(UU(L),IUS(L),L=1,6)
108   FORMAT(4A1,1X,2(F7.4,'(',I1,')',2X),4(F7.4,'(',I2,')',1X))
C-----sU11<10, sU22>10, sU33<10, sU12>10, sU13>10, sU23>10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).GE.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).GE.10.AND.IUS(6).GE.10)THEN
      WRITE(15,109)AAAA,(UU(L),IUS(L),L=1,6)
109   FORMAT(4A1,1X,F7.4,'(',I1,')',2X,F7.4,'(',I2,')',1X,
     1 F7.4,'(',I1,')',2X,3(F7.4,'(',I2,')',1X))
C-----sU11<10, sU22>10, sU33>10, sU12<10, sU13>10, sU23>10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).GE.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).GE.10.AND.IUS(6).GE.10)THEN
      WRITE(15,110)AAAA,(UU(L),IUS(L),L=1,6)
110   FORMAT(4A1,1X,F7.4,'(',I1,')',2X,2(F7.4,'(',I2,')',1X),
     1 F7.4,'(',I1,')',2X,2(F7.4,'(',I2,')',1X))
C-----sU11<10, sU22>10, sU33>10, sU12>10, sU13<10, sU23>10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).GE.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).LT.10.AND.IUS(6).GE.10)THEN
      WRITE(15,111)AAAA,(UU(L),IUS(L),L=1,6)
111   FORMAT(4A1,1X,F7.4,'(',I1,')',2X,3(F7.4,'(',I2,')',1X),
     1 F7.4,'(',I1,')',2X,F7.4,'(',I2,')')
C-----sU11<10, sU22>10, sU33>10, sU12>10, sU13>10, sU23<10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).GE.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).GE.10.AND.IUS(6).LT.10)THEN
      WRITE(15,112)AAAA,(UU(L),IUS(L),L=1,6)
112   FORMAT(4A1,1X,F7.4,'(',I1,')',2X,4(F7.4,'(',I2,')',1X),
     1 F7.4,'(',I1,')')
C-----sU11>10, sU22<10, sU33<10, sU12>10, sU13>10, sU23>10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).LT.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).GE.10.AND.IUS(6).GE.10)THEN
      WRITE(15,113)AAAA,(UU(L),IUS(L),L=1,6)
113   FORMAT(4A1,1X,F7.4,'(',I2,')',1X,2(F7.4,'(',I1,')',2X),
     1 3(F7.4,'(',I2,')',1X))
C-----sU11>10, sU22<10, sU33>10, sU12<10, sU13>10, sU23>10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).LT.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).GE.10.AND.IUS(6).GE.10)THEN
      WRITE(15,114)AAAA,(UU(L),IUS(L),L=1,6)
114   FORMAT(4A1,1X,F7.4,'(',I2,')',1X,F7.4,'(',I1,')',2X,
     1 F7.4,'(',I2,')',1X,F7.4,'(',I1,')',2X,2(F7.4,'(',I2,')',1X))
C-----sU11>10, sU22<10, sU33>10, sU12>10, sU13<10, sU23>10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).LT.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).LT.10.AND.IUS(6).GE.10)THEN
      WRITE(15,115)AAAA,(UU(L),IUS(L),L=1,6)
115   FORMAT(4A1,1X,F7.4,'(',I2,')',1X,F7.4,'(',I1,')',2X,
     1 2(F7.4,'(',I2,')',1X),F7.4,'(',I1,')',2X,F7.4,'(',I2,')')
C-----sU11>10, sU22<10, sU33>10, sU12>10, sU13>10, sU23<10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).LT.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).GE.10.AND.IUS(6).LT.10)THEN
      WRITE(15,116)AAAA,(UU(L),IUS(L),L=1,6)
116   FORMAT(4A1,1X,F7.4,'(',I2,')',1X,F7.4,'(',I1,')',2X,
     1 3(F7.4,'(',I2,')',1X),F7.4,'(',I1,')')
C-----sU11>10, sU22>10, sU33<10, sU12<10, sU13>10, sU23>10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).GE.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).GE.10.AND.IUS(6).GE.10)THEN
      WRITE(15,117)AAAA,(UU(L),IUS(L),L=1,6)
117   FORMAT(4A1,1X,2(F7.4,'(',I2,')',1X),2(F7.4,'(',I1,')',2X),
     1 2(F7.4,'(',I2,')',1X))
C-----sU11>10, sU22>10, sU33<10, sU12>10, sU13<10, sU23>10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).GE.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).LT.10.AND.IUS(6).GE.10)THEN
      WRITE(15,118)AAAA,(UU(L),IUS(L),L=1,6)
118   FORMAT(4A1,1X,2(F7.4,'(',I2,')',1X),F7.4,'(',I1,')',2X,
     1 F7.4,'(',I2,')',1X,F7.4,'(',I1,')',2X,F7.4,'(',I2,')')
C-----sU11>10, sU22>10, sU33<10, sU12>10, sU13>10, sU23<10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).GE.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).GE.10.AND.IUS(6).LT.10)THEN
      WRITE(15,119)AAAA,(UU(L),IUS(L),L=1,6)
119   FORMAT(4A1,1X,2(F7.4,'(',I2,')',1X),F7.4,'(',I1,')',2X,
     1 2(F7.4,'(',I2,')',1X),F7.4,'(',I1,')')
C-----sU11>10, sU22>10, sU33>10, sU12<10, sU13<10, sU23>10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).GE.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).LT.10.AND.IUS(6).GE.10)THEN
      WRITE(15,120)AAAA,(UU(L),IUS(L),L=1,6)
120   FORMAT(4A1,1X,3(F7.4,'(',I2,')',1X),2(F7.4,'(',I1,')',2X),
     1 F7.4,'(',I2,')')
C-----sU11>10, sU22>10, sU33>10, sU12<10, sU13>10, sU23<10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).GE.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).GE.10.AND.IUS(6).LT.10)THEN
      WRITE(15,121)AAAA,(UU(L),IUS(L),L=1,6)
121   FORMAT(4A1,1X,3(F7.4,'(',I2,')',1X),F7.4,'(',I1,')',2X,
     1 F7.4,'(',I2,')',1X,F7.4,'(',I1,')')
C-----sU11>10, sU22>10, sU33>10, sU12>10, sU13<10, sU23<10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).GE.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).LT.10.AND.IUS(6).LT.10)THEN
      WRITE(15,122)AAAA,(UU(L),IUS(L),L=1,6)
122   FORMAT(4A1,1X,4(F7.4,'(',I2,')',1X),2(F7.4,'(',I1,')',2X))
C-----sU11<10, sU22<10, sU33<10, sU12>10, sU13>10, sU23>10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).LT.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).GE.10.AND.IUS(6).GE.10)THEN
      WRITE(15,123)AAAA,(UU(L),IUS(L),L=1,6)
123   FORMAT(4A1,1X,3(F7.4,'(',I1,')',2X),3(F7.4,'(',I2,')',1X))
C-----sU11<10, sU22<10, sU33>10, sU12<10, sU13>10, sU23>10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).LT.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).GE.10.AND.IUS(6).GE.10)THEN
      WRITE(15,124)AAAA,(UU(L),IUS(L),L=1,6)
124   FORMAT(4A1,1X,2(F7.4,'(',I1,')',2X),F7.4,'(',I2,')',1X,
     1 F7.4,'(',I1,')',2X,2(F7.4,'(',I2,')',1X))
C-----sU11<10, sU22<10, sU33>10, sU12>10, sU13<10, sU23>10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).LT.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).LT.10.AND.IUS(6).GE.10)THEN
      WRITE(15,125)AAAA,(UU(L),IUS(L),L=1,6)
125   FORMAT(4A1,1X,2(F7.4,'(',I1,')',2X),2(F7.4,'(',I2,')',1X),
     1 F7.4,'(',I1,')',2X,F7.4,'(',I2,')')
C-----sU11<10, sU22<10, sU33>10, sU12>10, sU13>10, sU23<10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).LT.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).GE.10.AND.IUS(6).LT.10)THEN
      WRITE(15,126)AAAA,(UU(L),IUS(L),L=1,6)
126   FORMAT(4A1,1X,2(F7.4,'(',I1,')',2X),3(F7.4,'(',I2,')',1X),
     1 F7.4,'(',I1,')')
C-----sU11<10, sU22>10, sU33<10, sU12<10, sU13>10, sU23>10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).GE.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).GE.10.AND.IUS(6).GE.10)THEN
      WRITE(15,127)AAAA,(UU(L),IUS(L),L=1,6)
127   FORMAT(4A1,1X,F7.4,'(',I1,')',2X,F7.4,'(',I2,')',1X,
     1 2(F7.4,'(',I1,')',2X),2(F7.4,'(',I2,')',1X))
C-----sU11<10, sU22>10, sU33<10, sU12>10, sU13<10, sU23>10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).GE.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).LT.10.AND.IUS(6).GE.10)THEN
      WRITE(15,128)AAAA,(UU(L),IUS(L),L=1,6)
128   FORMAT(4A1,1X,3(F7.4,'(',I1,')',2X,F7.4,'(',I2,')',1X))
C-----sU11<10, sU22>10, sU33<10, sU12>10, sU13>10, sU23<10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).GE.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).GE.10.AND.IUS(6).LT.10)THEN
      WRITE(15,129)AAAA,(UU(L),IUS(L),L=1,6)
129   FORMAT(4A1,1X,2(F7.4,'(',I1,')',2X,F7.4,'(',I2,')',1X),
     1 F7.4,'(',I2,')',1X,F7.4,'(',I1,')')
C-----sU11<10, sU22>10, sU33>10, sU12<10, sU13<10, sU23>10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).GE.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).LT.10.AND.IUS(6).GE.10)THEN
      WRITE(15,130)AAAA,(UU(L),IUS(L),L=1,6)
130   FORMAT(4A1,1X,F7.4,'(',I1,')',2X,2(F7.4,'(',I2,')',1X),
     1 2(F7.4,'(',I1,')',2X),F7.4,'(',I2,')')
C-----sU11<10, sU22>10, sU33>10, sU12<10, sU13>10, sU23<10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).GE.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).GE.10.AND.IUS(6).LT.10)THEN
      WRITE(15,131)AAAA,(UU(L),IUS(L),L=1,6)
131   FORMAT(4A1,1X,F7.4,'(',I1,')',2X,2(F7.4,'(',I2,')',1X),
     1 F7.4,'(',I1,')',2X,F7.4,'(',I2,')',1X,F7.4,'(',I1,')')
C-----sU11<10, sU22>10, sU33>10, sU12>10, sU13<10, sU23<10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).GE.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).GE.10.AND.IUS(6).LT.10)THEN
      WRITE(15,132)AAAA,(UU(L),IUS(L),L=1,6)
132   FORMAT(4A1,1X,F7.4,'(',I1,')',2X,3(F7.4,'(',I2,')',1X),
     1 2(F7.4,'(',I1,')',2X))
C-----sU11>10, sU22<10, sU33<10, sU12<10, sU13>10, sU23>10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).LT.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).GE.10.AND.IUS(6).GE.10)THEN
      WRITE(15,133)AAAA,(UU(L),IUS(L),L=1,6)
133   FORMAT(4A1,1X,F7.4,'(',I2,')',1X,3(F7.4,'(',I1,')',2X),
     1 2(F7.4,'(',I2,')',1X))
C-----sU11>10, sU22<10, sU33<10, sU12>10, sU13<10, sU23>10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).LT.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).LT.10.AND.IUS(6).GE.10)THEN
      WRITE(15,134)AAAA,(UU(L),IUS(L),L=1,6)
134   FORMAT(4A1,1X,F7.4,'(',I2,')',1X,2(F7.4,'(',I1,')',2X),
     1 F7.4,'(',I2,')',1X,F7.4,'(',I1,')',2X,F7.4,'(',I2,')')
C-----sU11>10, sU22<10, sU33<10, sU12>10, sU13>10, sU23<10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).LT.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).GE.10.AND.IUS(6).LT.10)THEN
      WRITE(15,135)AAAA,(UU(L),IUS(L),L=1,6)
135   FORMAT(4A1,1X,F7.4,'(',I2,')',1X,2(F7.4,'(',I1,')',2X),
     1 2(F7.4,'(',I2,')',1X),F7.4,'(',I1,')')
C-----sU11>10, sU22<10, sU33>10, sU12<10, sU13<10, sU23>10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).LT.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).LT.10.AND.IUS(6).GE.10)THEN
      WRITE(15,136)AAAA,(UU(L),IUS(L),L=1,6)
136   FORMAT(4A1,1X,F7.4,'(',I2,')',1X,F7.4,'(',I1,')',2X,
     1 F7.4,'(',I2,')',1X,2(F7.4,'(',I1,')',2X),F7.4,'(',I2,')')
C-----sU11>10, sU22<10, sU33>10, sU12<10, sU13>10, sU23<10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).LT.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).GE.10.AND.IUS(6).LT.10)THEN
      WRITE(15,137)AAAA,(UU(L),IUS(L),L=1,6)
137   FORMAT(4A1,1X,F7.4,'(',I2,')',1X,F7.4,'(',I1,')',2X,
     1 F7.4,'(',I2,')',1X,F7.4,'(',I1,')',2X,F7.4,'(',I2,')',1X,
     2 F7.4,'(',I1,')')
C-----sU11>10, sU22<10, sU33>10, sU12>10, sU13<10, sU23<10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).LT.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).LT.10.AND.IUS(6).LT.10)THEN
      WRITE(15,138)AAAA,(UU(L),IUS(L),L=1,6)
138   FORMAT(4A1,1X,F7.4,'(',I2,')',1X,F7.4,'(',I1,')',2X,
     1 2(F7.4,'(',I2,')',1X),2(F7.4,'(',I1,')',2X))
C-----sU11>10, sU22>10, sU33<10, sU12<10, sU13<10, sU23>10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).GE.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).LT.10.AND.IUS(6).GE.10)THEN
      WRITE(15,139)AAAA,(UU(L),IUS(L),L=1,6)
139   FORMAT(4A1,1X,2(F7.4,'(',I2,')',1X),3(F7.4,'(',I1,')',2X),
     1 F7.4,'(',I2,')')
C-----sU11>10, sU22>10, sU33<10, sU12<10, sU13>10, sU23<10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).GE.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).GE.10.AND.IUS(6).LT.10)THEN
      WRITE(15,140)AAAA,(UU(L),IUS(L),L=1,6)
140   FORMAT(4A1,1X,2(F7.4,'(',I2,')',1X),2(F7.4,'(',I1,')',2X),
     1 F7.4,'(',I2,')',1X,F7.4,'(',I1,')')
C-----sU11>10, sU22>10, sU33<10, sU12>10, sU13<10, sU23<10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).GE.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).LT.10.AND.IUS(6).LT.10)THEN
      WRITE(15,141)AAAA,(UU(L),IUS(L),L=1,6)
141   FORMAT(4A1,1X,2(F7.4,'(',I2,')',1X),F7.4,'(',I1,')',2X,
     1 F7.4,'(',I2,')',1X,2(F7.4,'(',I1,')',2X))
C-----sU11>10, sU22>10, sU33>10, sU12<10, sU13<10, sU23<10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).GE.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).LT.10.AND.IUS(6).LT.10)THEN
      WRITE(15,142)AAAA,(UU(L),IUS(L),L=1,6)
142   FORMAT(4A1,1X,3(F7.4,'(',I2,')',1X),3(F7.4,'(',I1,')',2X))
C-----sU11<10, sU22<10, sU33<10, sU12<10, sU13>10, sU23>10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).LT.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).GE.10.AND.IUS(6).GE.10)THEN
      WRITE(15,143)AAAA,(UU(L),IUS(L),L=1,6)
143   FORMAT(4A1,1X,4(F7.4,'(',I1,')',2X),2(F7.4,'(',I2,')',1X))
C-----sU11<10, sU22<10, sU33<10, sU12>10, sU13<10, sU23>10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).LT.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).LT.10.AND.IUS(6).GE.10)THEN
      WRITE(15,144)AAAA,(UU(L),IUS(L),L=1,6)
144   FORMAT(4A1,1X,3(F7.4,'(',I1,')',2X),F7.4,'(',I2,')',1X,
     1 F7.4,'(',I1,')',2X,F7.4,'(',I2,')')
C-----sU11<10, sU22<10, sU33<10, sU12>10, sU13>10, sU23<10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).LT.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).GE.10.AND.IUS(6).LT.10)THEN
      WRITE(15,145)AAAA,(UU(L),IUS(L),L=1,6)
145   FORMAT(4A1,1X,3(F7.4,'(',I1,')',2X),2(F7.4,'(',I2,')',1X),
     1 F7.4,'(',I1,')')
C-----sU11>10, sU22<10, sU33<10, sU12<10, sU13<10, sU23>10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).LT.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).LT.10.AND.IUS(6).GE.10)THEN
      WRITE(15,146)AAAA,(UU(L),IUS(L),L=1,6)
146   FORMAT(4A1,1X,F7.4,'(',I2,')',1X,4(F7.4,'(',I1,')',2X),
     1 F7.4,'(',I2,')')
C-----sU11>10, sU22<10, sU33<10, sU12<10, sU13>10, sU23<10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).LT.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).GE.10.AND.IUS(6).LT.10)THEN
      WRITE(15,147)AAAA,(UU(L),IUS(L),L=1,6)
147   FORMAT(4A1,1X,F7.4,'(',I2,')',1X,3(F7.4,'(',I1,')',2X),
     1 F7.4,'(',I2,')',1X,F7.4,'(',I1,')')
C-----sU11>10, sU22>10, sU33<10, sU12<10, sU13<10, sU23<10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).GE.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).LT.10.AND.IUS(6).LT.10)THEN
      WRITE(15,148)AAAA,(UU(L),IUS(L),L=1,6)
148   FORMAT(4A1,1X,2(F7.4,'(',I2,')',1X),4(F7.4,'(',I1,')',2X))
C-----sU11>10, sU22<10, sU33>10, sU12<10, sU13<10, sU23<10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).LT.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).LT.10.AND.IUS(6).LT.10)THEN
      WRITE(15,149)AAAA,(UU(L),IUS(L),L=1,6)
149   FORMAT(4A1,1X,F7.4,'(',I2,')',1X,F7.4,'(',I1,')',2X,
     1 F7.4,'(',I2,')',1X,3(F7.4,'(',I1,')',2X))
C-----sU11>10, sU22<10, sU33<10, sU12>10, sU13<10, sU23<10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).LT.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).LT.10.AND.IUS(6).LT.10)THEN
      WRITE(15,150)AAAA,(UU(L),IUS(L),L=1,6)
150   FORMAT(4A1,1X,F7.4,'(',I2,')',1X,2(F7.4,'(',I1,')',2X),
     1 F7.4,'(',I2,')',1X,2(F7.4,'(',I1,')',2X))
C-----sU11<10, sU22>10, sU33>10, sU12<10, sU13<10, sU23<10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).GE.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).LT.10.AND.IUS(6).LT.10)THEN
      WRITE(15,151)AAAA,(UU(L),IUS(L),L=1,6)
151   FORMAT(4A1,1X,F7.4,'(',I1,')',2X,2(F7.4,'(',I2,')',1X),
     1 3(F7.4,'(',I1,')',2X))
C-----sU11<10, sU22>10, sU33<10, sU12>10, sU13<10, sU23<10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).GE.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).LT.10.AND.IUS(6).LT.10)THEN
      WRITE(15,152)AAAA,(UU(L),IUS(L),L=1,6)
152   FORMAT(4A1,1X,F7.4,'(',I1,')',2X,F7.4,'(',I2,')',1X,
     1 F7.4,'(',I1,')',2X,F7.4,'(',I2,')',1X,2(F7.4,'(',I1,')',2X))
C-----sU11<10, sU22>10, sU33<10, sU12<10, sU13>10, sU23<10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).GE.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).GE.10.AND.IUS(6).LT.10)THEN
      WRITE(15,153)AAAA,(UU(L),IUS(L),L=1,6)
153   FORMAT(4A1,1X,F7.4,'(',I1,')',2X,F7.4,'(',I2,')',1X,
     1 2(F7.4,'(',I1,')',2X),F7.4,'(',I2,')',1X,F7.4,'(',I1,')',2X)
C-----sU11<10, sU22>10, sU33<10, sU12<10, sU13<10, sU23>10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).GE.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).LT.10.AND.IUS(6).GE.10)THEN
      WRITE(15,154)AAAA,(UU(L),IUS(L),L=1,6)
154   FORMAT(4A1,1X,F7.4,'(',I1,')',2X,F7.4,'(',I2,')',1X,
     1 3(F7.4,'(',I1,')',2X),F7.4,'(',I2,')',1X)
C-----sU11<10, sU22<10, sU33>10, sU12>10, sU13<10, sU23<10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).LT.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).LT.10.AND.IUS(6).LT.10)THEN
      WRITE(15,155)AAAA,(UU(L),IUS(L),L=1,6)
155   FORMAT(4A1,1X,2(F7.4,'(',I1,')',2X),2(F7.4,'(',I2,')',1X),
     1 2(F7.4,'(',I1,')',2X))
C-----sU11<10, sU22<10, sU33>10, sU12<10, sU13>10, sU23<10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).LT.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).GE.10.AND.IUS(6).LT.10)THEN
      WRITE(15,156)AAAA,(UU(L),IUS(L),L=1,6)
156   FORMAT(4A1,1X,2(F7.4,'(',I1,')',2X),F7.4,'(',I2,')',1X,
     1 F7.4,'(',I1,')',2X,F7.4,'(',I2,')',1X,F7.4,'(',I1,')',2X)
C-----sU11<10, sU22<10, sU33>10, sU12<10, sU13<10, sU23>10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).LT.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).LT.10.AND.IUS(6).GE.10)THEN
      WRITE(15,157)AAAA,(UU(L),IUS(L),L=1,6)
157   FORMAT(4A1,1X,2(F7.4,'(',I1,')',2X),F7.4,'(',I2,')',1X,
     1 2(F7.4,'(',I1,')',2X),F7.4,'(',I2,')',1X)
C-----sU11<10, sU22<10, sU33<10, sU12<10, sU13<10, sU23>10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).LT.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).LT.10.AND.IUS(6).GE.10)THEN
      WRITE(15,158)AAAA,(UU(L),IUS(L),L=1,6)
158   FORMAT(4A1,1X,5(F7.4,'(',I1,')',2X),F7.4,'(',I2,')')
C-----sU11<10, sU22<10, sU33<10, sU12<10, sU13>10, sU23<10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).LT.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).GE.10.AND.IUS(6).LT.10)THEN
      WRITE(15,159)AAAA,(UU(L),IUS(L),L=1,6)
159   FORMAT(4A1,1X,4(F7.4,'(',I1,')',2X),F7.4,'(',I2,')',1X,
     1 F7.4,'(',I1,')')
C-----sU11<10, sU22<10, sU33<10, sU12>10, sU13<10, sU23<10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).LT.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).GE.10.AND.IUS(5).LT.10.AND.IUS(6).LT.10)THEN
      WRITE(15,160)AAAA,(UU(L),IUS(L),L=1,6)
160   FORMAT(4A1,1X,3(F7.4,'(',I1,')',2X),F7.4,'(',I2,')',1X,
     1 2(F7.4,'(',I1,')',2X))
C-----sU11<10, sU22<10, sU33>10, sU12<10, sU13<10, sU23<10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).LT.10.AND.IUS(3).GE.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).LT.10.AND.IUS(6).LT.10)THEN
      WRITE(15,161)AAAA,(UU(L),IUS(L),L=1,6)
161   FORMAT(4A1,1X,2(F7.4,'(',I1,')',2X),F7.4,'(',I2,')',1X,
     1 3(F7.4,'(',I1,')',2X))
C-----sU11<10, sU22>10, sU33<10, sU12<10, sU13<10, sU23<10
      ELSEIF(IUS(1).LT.10.AND.IUS(2).GE.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).LT.10.AND.IUS(6).LT.10)THEN
      WRITE(15,162)AAAA,(UU(L),IUS(L),L=1,6)
162   FORMAT(4A1,1X,F7.4,'(',I1,')',2X,F7.4,'(',I2,')',1X,
     1 4(F7.4,'(',I1,')',2X))
C-----sU11>10, sU22<10, sU33<10, sU12<10, sU13<10, sU23<10
      ELSEIF(IUS(1).GE.10.AND.IUS(2).LT.10.AND.IUS(3).LT.10.AND.
     1 IUS(4).LT.10.AND.IUS(5).LT.10.AND.IUS(6).LT.10)THEN
      WRITE(15,163)AAAA,(UU(L),IUS(L),L=1,6)
163   FORMAT(4A1,1X,F7.4,'(',I2,')',1X,5(F7.4,'(',I1,')',2X))
      ENDIF
2     RETURN
      END
 
      SUBROUTINE ANOMDIS(AA,ALA,F1,F2,NMT)
C-----Find the anomalous dispersion coefficients, f' and f", for the
C-----atom AA  (2A1)
      CHARACTER*1 AA(2),ATM(98,2)
      CHARACTER*12 NOMAT(98),NMT
      DIMENSION FCU(98,2),FMO(98,2)
      DATA ((FCU(I,J),J=1,2),I=1,52)/.0,.0,.0,.0,.0008,.0003,.0038,
     1 .0014,.0090,.0039,.0181,.0091,.0311,.0180,.0492,.0322,.0727,
     2 .0534,.1019,.0833,.1353,.1239,.1719,.1771,.2130,.2455,.2541,
     3 .3302,.2955,.4335,.3331,.5567,.3639,.7018,.3843,.8717,.3868,
     4 1.0657,.3641,1.2855,.3119,1.5331,.2191,1.8069,.0687,2.1097,
     5 -.1635,2.4439,-.5299,2.8052,-1.1336,3.1974,-2.3653,3.6143,
     6 -3.0029,.5091,-1.9646,.5888,-1.5491,.6778,-1.2846,.7763,-1.0885,
     7 .8855,-0.9300,1.0051,-.7943,1.1372,-.6763,1.2805,-.5657,1.4385,
     8 -.4688,1.6079,-.3528,1.8200,-.2670,2.0244,-.1862,2.2449,-.1121,
     9 2.4826,-.0483,2.7339,.0057,3.0049,.0552,3.2960,.0927,3.6045,
     1 .1215,3.9337,.1306,4.2820,.1185,4.6533,.0822,5.0449,.0259,
     2 5.4591,-.0562,5.8946,-.1759,6.3531/
      DATA ((FCU(I,J),J=1,2),I=53,96)/-.3257,6.8362,-.5179,7.3500,
     1 -0.7457,7.9052,-1.0456,8.4617,-1.4094,9.0376,-1.8482,9.6596,
     2 -2.4164,10.2820,-3.1807,10.9079,-4.0598,11.5523,-5.3236,12.2178,
     3 -8.9294,11.1857,-8.8380,11.9157,-9.1472,9.1891,-9.8046,9.8477,
     4 -14.9734,3.7046,-9.4367,3.9380,-8.0393,4.1821,-7.2108,4.4329,
     5 -6.6179,4.6937,-6.1794,4.9776,-5.7959,5.2718,-5.4734,5.5774,
     6 -5.2083,5.8923,-4.9801,6.2216,-4.7710,6.5667,-4.5932,6.9264,
     7 -4.4197,7.2980,-4.2923,7.6849,-4.1627,8.0900,-4.0753,8.5060,
     8 -4.0111,8.9310,-3.9670,9.3834,-3.9588,9.8433,-3.9487,10.3181,
     9 -3.9689,10.8038,-4.0088,11.2969,-4.0794,11.7994,-4.1491,12.3296,
     1 -4.2473,12.8681,-4.3638,13.4090,-4.5053,13.9666,-4.6563,14.3729,
     2 -4.8483,15.0877,-5.0611,15.6355/
      DATA ((FCU(I,J),J=1,2),I=97,98)/-5.3481,16.3190,-5.5545,16.7428/
      DATA ((FMO(I,J),J=1,2),I=1,52)/.0,.0,.0,.0,-.0003,.0001,.0005,
     1 .0002,.0013,.0007,.0033,.0016,.0061,.0033,.0106,.0060,.0171,
     2 .0103,.0259,.0164,.0362,.0249,.0486,.0363,.0645,.0514,.0817,
     3 .0704,.1023,.0942,.1246,.1234,.1484,.1585,.1743,.2003,.2009,
     4 .2494,.2262,.3064,.2519,.3716,.2776,.4457,.3005,.5294,.3209,
     5 .6236,.3368,.7283,.3463,.8444,.3494,.9721,.3393,1.1124,.3201,
     6 1.2651,.2839,1.4301,.2307,1.6083,.1547,1.8001,.0499,2.0058,
     7 -.0929,2.2259,-.2901,2.4595,-.5574,2.7079,-.9393,2.9676,-1.5307,
     8 3.2498,-2.7962,3.5667,-2.9673,.5597,-2.0727,.6215,-1.6832,.6857,
     9 -1.4390,.7593,-1.2594,.8363,-1.1178,.9187,-.9988,1.0072,-.8971,
     1 1.1015,-.8075,1.2024,-.7276,1.3100,-.6537,1.4246,-.5866,1.5461,
     2 -.5308,1.6751/
      DATA ((FMO(I,J),J=1,2),I=53,98)/-.4742,1.8119,-.4205,1.9578,
     1 -.3680,2.1192,-.3244,2.2819,-.2871,2.4523,-.2486,2.6331,-.2180,
     2 2.8214,-.1943,3.0179,-.1753,3.2249,-.1638,3.4418,-.1578,3.6682,
     3 -.1653,3.9035,-.1723,4.1537,-.1892,4.4098,-.2175,4.6783,-.2586,
     4 4.9576,-.3139,5.2483,-.3850,5.5486,-.4720,5.8584,-.5830,6.1852,
     5 -.7052,6.5227,-.8490,6.8722,-1.0185,7.2310,-1.2165,7.6030,
     6 -1.4442,7.9887,-1.7033,8.3905,-2.0133,8.8022,-2.3894,9.2266,
     7 -2.8358,9.6688,-3.3944,10.1111,-4.1077,10.2566,-5.1210,11.0496,
     7 -7.9122,9.9777,-8.0659,10.4580,-7.2224,7.7847,-6.7704,8.1435,
     8 -6.8494,8.5178,-7.2400,8.8979,-8.0334,9.2807,-9.6767,9.6646,
     9 -11.4937,4.1493,-9.4100,4.3056,-7.8986,4.5125,-7.3248,4.6980,
     1 -6.8498,4.9086,-6.6561,5.0785/
      DATA ((ATM(I,J),J=1,2),I=1,52)/'H',' ','H','E','L','I','B','E',
     1 'B',' ','C',' ','N',' ','O',' ','F',' ','N','E','N','A','M','G',
     2 'A','L','S','I','P',' ','S',' ','C','L','A','R','K',' ','C','A',
     3 'S','C','T','I','V',' ','C','R','M','N','F','E','C','O','N','I',
     4 'C','U','Z','N','G','A','G','E','A','S','S','E','B','R','K','R',
     5 'R','B','S','R','Y',' ','Z','R','N','B','M','O','T','C','R','U',
     6 'R','H','P','D','A','G','C','D','I','N','S','N','S','B','T','E'/
      DATA ((ATM(I,J),J=1,2),I=53,98)/'I',' ','X','E','C','S','B','A',
     1 'L','A','C','E','P','R','N','D','P','M','S','M','E','U','G','D',
     2 'T','B','D','Y','H','O','E','R','T','M','Y','B','L','U','H','F',
     3 'T','A','W',' ','R','E','O','S','I','R','P','T','A','U','H','G',
     4 'T','L','P','B','B','I','P','O','A','T','R','N','F','R','R','A',
     5 'A','C','T','H','P','A','U',' ','N','P','P','U','A','M','C','M',
     6 'B','K','C','F'/
      DATA (NOMAT(I),I=1,38)/'Hydrogen    ','Helium      ',
     1 'Lithium     ','Berillium   ','Boron       ','Carbon      ',
     2 'Nitrogen    ','Oxygen      ','Fluorine    ','Neon        ',
     3 'Sodium      ','Magnesium   ','Aluminium   ','Silicium    ',
     4 'Phosphorus  ','Sulphur     ','Chlorine    ','Argon       ',
     5 'Potassium   ','Calcium     ','Scandium    ','Titanium    ',
     6 'Vanadium    ','Chromium    ','Manganese   ','Iron        ',
     7 'Cobalt      ','Nickel      ','Copper      ','Zinc        ',
     8 'Gallium     ','Germanium   ','Arsenic     ','Selenium    ',
     9 'Bromine     ','Krypton     ','Rubidium    ','Strontium   '/
      DATA (NOMAT(I),I=39,76)/'Yttrium     ','Zirconium   ',
     1 'Niobium     ','Molibdenum  ','Technetium  ','Ruthenium   ',
     2 'Rhodium     ','Palladium   ','Siver       ','Cadmium     ',
     3 'Indium      ','Tin         ','Antimony    ','Tellurium   ',
     4 'Iodine      ','Xenon       ','Caesium     ','Barium      ',
     5 'Lanthanum   ','Cerium      ','Praseodymium','Neodimium   ',
     6 'Promethium  ','Samarium    ','Europium    ','Gadolinium  ',
     7 'Terbium     ','Dysprosium  ','Holmium     ','Erbium      ',
     8 'Thulium     ','Ytterbium   ','Lutetium    ','Hafnium     ',
     9 'Tantalum    ','Tungsten    ','Rhenium     ','Osmium      '/
      DATA (NOMAT(I),I=77,98)/'Iridium     ','Platinum    ',
     1 'Gold        ','Mercury     ','Thallium    ','Lead        ',
     2 'Bismuth     ','Polonium    ','Astatine    ','Radon       ',
     3 'Francium    ','Radium      ','Actinium    ','Thorium     ',
     4 'Protactinium','Uranium     ','Neptunium   ','Plutonium   ',
     5 'Americium   ','Curium      ','Berkelium   ','Californium '/
      DO 1 I=1,98
      IF(AA(1).NE.ATM(I,1))GO TO 1
      IF(AA(2).NE.ATM(I,2))GO TO 1
      NMT=NOMAT(I)
      IF(ALA.GT.1.0)THEN
      F1=FCU(I,1)
      F2=FCU(I,2)
      ELSE
      F1=FMO(I,1)
      F2=FMO(I,2)
      ENDIF
      GO TO 2
1     CONTINUE
2     RETURN
      END
 
      SUBROUTINE NUMAT(NP,NH,Z,SPC,NSP)
C-----Count the number of atoms of each species in the unit cell
      CHARACTER*1 ATM(200,4),STR3(11),BP(200,2),SPC(20,2)
      DIMENSION NSP(20)
      COMMON/GRP1/ATM
     1      /GRP2/STR3
      DO 2 I=1,NP
      BP(I,1)=ATM(I,1)
      DO 1 J=1,11
      IF(ATM(I,2).NE.STR3(J))GO TO 1
      BP(I,2)=' '
      GO TO 2
1     CONTINUE
      BP(I,2)=ATM(I,2)
2     CONTINUE
      SPC(1,1)=BP(1,1)
      SPC(1,2)=BP(1,2)
      NS=1
      DO 5 I=2,NP
      DO 4 J=1,NS
      IF(BP(I,1).NE.SPC(J,1).OR.BP(I,2).NE.SPC(J,2))GO TO 4
      GO TO 5
4     CONTINUE
      NS=NS+1
      SPC(NS,1)=BP(I,1)
      SPC(NS,2)=BP(I,2)
5     CONTINUE
      DO 6 I=1,NS
      NSP(I)=0
      DO 6 J=1,NP
      IF(SPC(I,1).NE.BP(J,1).OR.SPC(I,2).NE.BP(J,2))GO TO 6
      NSP(I)=NSP(I)+1
6     CONTINUE
      DO 7 I=1,NS
7     NSP(I)=NSP(I)*Z
      SPC(NS+1,1)='H'
      SPC(NS+1,2)=' '
      NSP(NS+1)=NH*Z
      RETURN
      END
 
      BLOCK DATA
      CHARACTER*1 STR3(11),MINU(26),MAIU(26)
      COMMON/GRP2/STR3
     1      /GRP3/MINU
     2      /GRP4/MAIU
      DATA MINU/'a','b','c','d','e','f','g','h','i','j','k','l','m',
     1 'n','o','p','q','r','s','t','u','v','w','x','y','z'/
      DATA MAIU/'A','B','C','D','E','F','G','H','I','J','K','L','M',
     1 'N','O','P','Q','R','S','T','U','V','W','X','Y','Z'/
      DATA STR3/'0','1','2','3','4','5','6','7','8','9',' '/
      END
 
      SUBROUTINE MINUSC(AA)
      CHARACTER*1 AA,MINU(26),MAIU(26)
      COMMON/GRP3/MINU
     1      /GRP4/MAIU
      DO 1 I=1,26
      IF(AA.NE.MAIU(I))GO TO 1
      AA=MINU(I)
      GO TO 2
1     CONTINUE
2     RETURN
      END
 
      SUBROUTINE HDR(ATM,KD)
C-----This subroutine sets KD=0 for a non-H atom
      CHARACTER*1 ATM(4),STR(5)
      DATA STR/'A','E','F','G','O'/
      KD=0
      IF(ATM(1).NE.'H') GO TO 3
      DO 1 I=1,5
      IF(ATM(2).EQ.STR(I)) GO TO 3
1     CONTINUE
      KD=1
3     RETURN
      END
 
      SUBROUTINE ROUNDOFF(KD1,KD2,X,SX)
C-----Write the cell constants and volume with rounded off e.s.d.'s
      CHARACTER*1 AA
      CHARACTER*5 BB
      DIMENSION N(5)
      DO 1 I=1,5
      SS=(10.0)**I/10.0
      N(I)=SX*SS+0.000005
1     CONTINUE
      IF(N(1).NE.0)THEN
      IS=(SX+0.5)
      KK=1
      GO TO 6
      ELSEIF(N(2).NE.0)THEN
      IS=(SX+0.05)*10
      KK=2
      GO TO 6
      ELSEIF(N(3).NE.0)THEN
      IS=(SX+0.005)*100
      KK=3
      GO TO 6
      ELSEIF(N(4).NE.0)THEN
      IS=(SX+0.0005)*1000
      KK=4
      GO TO 6
      ELSEIF(N(5).NE.0)THEN
      IS=(SX+0.00005)*10000
      KK=5
6     ENDIF
      IF(KD1.EQ.3)GO TO 4
      IF(KD1.EQ.2)GO TO 2
C-----Cell lengths
      IF(KD2.EQ.1)AA='a'
      IF(KD2.EQ.2)AA='b'
      IF(KD2.EQ.3)AA='c'
      IF(KK.EQ.1)WRITE(15,100)AA,X,IS
100   FORMAT(/'_cell_length_',A1,34X,F4.0,'(',I1,')')
      IF(KK.EQ.2)WRITE(15,101)AA,X,IS
101   FORMAT('_cell_length_',A1,31X,F5.1,'(',I1,')')
      IF(KK.EQ.3)WRITE(15,102)AA,X,IS
102   FORMAT('_cell_length_',A1,31X,F6.2,'(',I1,')')
      IF(KK.EQ.4)WRITE(15,103)AA,X,IS
103   FORMAT('_cell_length_',A1,31X,F7.3,'(',I1,')')
      IF(KK.EQ.5)WRITE(15,104)AA,X,IS
104   FORMAT('_cell_length_',A1,31X,F8.4,'(',I1,')')
      GO TO 5
C-----Cell angles
2     IF(KD2.EQ.1)BB='alpha'
      IF(KD2.EQ.2)BB='beta '
      IF(KD2.EQ.3)BB='gamma'
      IF(SX.LT.0.005)IS=0
      IF(SX.GE.0.005.AND.SX.LE.0.01)IS=1
      IF(KK.GT.3) KK=3
      IF(KK.EQ.1)WRITE(15,105)BB,X,IS
105   FORMAT('_cell_angle_',A5,28X,F4.0,'(',I1,')')
      IF(KK.EQ.2)WRITE(15,106)BB,X,IS
106   FORMAT('_cell_angle_',A5,28X,F5.1,'(',I1,')')
      IF(KK.EQ.3)WRITE(15,107)BB,X,IS
107   FORMAT('_cell_angle_',A5,28X,F6.2,'(',I1,')')
      GO TO 5
C-----Cell volume
4     IF(SX.LT.0.001)IS=0
      IF(KK.GT.3) KK=3
      IF(KK.EQ.1)WRITE(15,108)X,IS
108   FORMAT('_cell_volume',30X,F7.0,'(',I1,')')
      IF(KK.EQ.2)WRITE(15,109)X,IS
109   FORMAT('_cell_volume',30X,F8.1,'(',I1,')')
      IF(KK.EQ.3)WRITE(15,110)X,IS
110   FORMAT('_cell_volume',30X,F9.2,'(',I1,')')
5     RETURN
      END
 
      SUBROUTINE HYDRCIF
C-----Read from the output of PARST the hydrogen bond table for CIF
      CHARACTER*1 TIT(80),STR(8),STR1(8),DUM(8)
      CHARACTER*2 CC
      CHARACTER*4 ATM(3,50),AAA0
      CHARACTER*38 PE(50)
      DIMENSION NE(50),X(4,50),SX(4,50),KX(4),KK(50),NPE(50)
C     DATA (STR(I),I=1,8)/'h','y','d','r','o','g','e','n'/
      DATA (STR1(I),I=1,8)/'H','Y','D','R','O','G','E','N'/
1     READ(13,'(80A1)',END=22)TIT
      DO 24 I=1,8
24    DUM(I)=TIT(20+I)
      NN=8
      CALL MINUMA1(NN,DUM)
      DO 2 I=1,8
      IF(DUM(I).NE.STR1(I))GO TO 1
2     CONTINUE
      BACKSPACE (13,ERR=20)
      READ(13,'(34X,I4)')N
      DO 3 I=1,6
3     READ(13,'(80A1)')TIT
      NP=0
4     CONTINUE
      NP=NP+1
      READ(13,'(A2)')CC
      IF(CC.EQ.' ')GO TO 5
      BACKSPACE(13)
      READ(13,'(2X,I2,4X,A38)')NE(NP),PE(NP)
C     NE(I)=NE(I)+1
      GO TO 4
5     NP=NP-1
      N1=N*4+NP+8
      DO 6 I=1,N1
6     BACKSPACE (13,ERR=21)
      NH=0
      DO 9 I=1,N
      NH=NH+1
      READ(13,100)(ATM(J,NH),J=1,3),NPE(NH)
100   FORMAT(2X,A4,2X,A4,11X,A4,1X,I2)
      READ(13,101)(X(K,NH),SX(K,NH),K=1,4)
101   FORMAT(F6.3,1X,F4.3,7X,F5.3,1X,F4.3,8X,F5.3,1X,F4.3,10X,F6.2,
     1 1X,F5.2)
      READ(13,'(80A1)')TIT
      READ(13,'(80A1)')TIT
      AAA0=ATM(1,NH)
      IF(AAA0(1:1).EQ.'C'.AND.X(3,NH).GT.2.4.OR.X(4,NH).LT.100.0)THEN
      NH=NH-1
      GO TO 8
      ELSE
      DO 7 L=1,NP
      KK(NH)=L
      IF(NPE(NH).EQ.NE(L))GO TO 8
7     CONTINUE
      WRITE(15,'(''Error in equivalent positions'')')
      RETURN
8     ENDIF
9     CONTINUE
      IF(NH.EQ.0)GO TO 22
      WRITE(15,109)
109   FORMAT(/'loop_'/'_publ_manuscript_incl_extra_item'/
     1 2X,'''_geom_bond_atom_site_label_D'''/
     2 2X,'''_geom_bond_atom_site_label_H'''/
     3 2X,'''_geom_contact_atom_site_label_A'''/
     4 2X,'''_geom_bond_distance_DH'''/
     5 2X,'''_geom_contact_distance_HA'''/
     6 2X,'''_geom_contact_distance_DA'''/
     7 2X,'''_geom_angle_DHA'''/
     8 2X,'''_geom_contact_site_symmetry_A'''/)
      WRITE(15,110)
110   FORMAT('loop_'/'_geom_bond_atom_site_label_D'/
     1 '_geom_bond_atom_site_label_H'/
     2 '_geom_contact_atom_site_label_A'/
     3 '_geom_bond_distance_DH'/
     4 '_geom_contact_distance_HA'/
     5 '_geom_contact_distance_DA'/
     6 '_geom_angle_DHA'/
     7 '_geom_contact_site_symmetry_A')
      WRITE(15,108)
108   FORMAT('#'/'#  B-H...A',8X,'D-H',5X,'D...A',5X,'H...A',3X,
     1 'D-H...A'/'#')
      DO 23 I=1,NH
C-----sigma(D-H)<0.01, sigma(D...A)<0.01, sigma(H...A)<0.01,
C-----sigma(D-H...A)<1.0
      IF(SX(1,I).LT..01.AND.SX(2,I).LT..01.AND.SX(3,I).LT..01.AND.
     1 SX(4,I).LT.1.) THEN
      KX(1)=(SX(1,I)+0.0005)*1000
      KX(2)=(SX(2,I)+0.0005)*1000
      KX(3)=(SX(3,I)+0.0005)*1000
      KX(4)=(SX(4,I)+0.05)*10
      WRITE(15,102)(ATM(J,I),J=1,3),(X(K,I),KX(K),K=1,4),PE(KK(I))
102   FORMAT(3(1X,A4),2(F6.3,'(',I1,')'),F7.3,'(',I1,')',
     1 F6.1,'(',I1,')',A38)
      GO TO 10
C-----sigma(D-H)>=0.01,  sigma(D...A)<0.01,  sigma(H...A)>=0.01,
C-----sigma(D-H...A)<1.0
      ELSEIF(SX(1,I).GE..01.AND.SX(2,I).LT..01.AND.SX(3,I).GE..01.AND.
     1 SX(4,I).LT.1.) THEN
      KX(1)=(SX(1,I)+0.005)*100
      KX(2)=(SX(2,I)+0.0005)*1000
      KX(3)=(SX(3,I)+0.005)*100
      KX(4)=(SX(4,I)+0.05)*10
      WRITE(15,103)(ATM(J,I),J=1,3),(X(K,I),KX(K),K=1,4),PE(KK(I))
103   FORMAT(3(1X,A4),F5.2,'(',I1,')',F7.3,'(',I1,')',F6.2,'(',I1,')',
     1 F7.1,'(',I1,')',A38)
      GO TO 10
C-----sigma(D-H)>=0.01,  sigma(D...A)>=0.01,  sigma(H...A)>=0.01,
C-----sigma(D-H...A)<1.0
      ELSEIF(SX(1,I).GE..01.AND.SX(2,I).LT..01.AND.SX(3,I).GE..01.AND.
     1 SX(4,I).GE.1.) THEN
      KA=(X(4,I)+0.5)
      KX(1)=(SX(1,I)+0.005)*100
      KX(2)=(SX(2,I)+0.0005)*1000
      KX(3)=(SX(3,I)+0.005)*100
      KX(4)=(SX(4,I)+0.5)
      WRITE(15,104)(ATM(J,I),J=1,3),(X(K,I),KX(K),K=1,3),KA,KX(4),
     1 PE(KK(I))
104   FORMAT(3(1X,A4),F5.2,'(',I1,')',F7.3,'(',I1,')',F6.2,'(',I1,')',
     1 I5,'(',I1,')',2X,A38)
      GO TO 10
C-----sigma(D-H)>=0.01,  sigma(D...A)>=0.01,  sigma(H...A)>=0.01,
C-----sigma(D-H...A)<1.0
      ELSEIF(SX(1,I).GE..01.AND.SX(2,I).GE..01.AND.SX(3,I).GE..01.AND.
     1 SX(4,I).LT.1.) THEN
      KX(1)=(SX(1,I)+0.005)*100
      KX(2)=(SX(2,I)+0.005)*100
      KX(3)=(SX(3,I)+0.005)*100
      KX(4)=(SX(4,I)+0.05)*10
      WRITE(15,105)(ATM(J,I),J=1,3),(X(K,I),KX(K),K=1,4),PE(KK(I))
105   FORMAT(3(1X,A4),F5.2,'(',I1,')',F6.2,'(',I1,')',F7.2,'(',I1,')',
     1 F7.1,'(',I1,')',A38)
      GO TO 10
C-----sigma(D-H)>=0.01,  sigma(D...A)>=0.01,  sigma(H...A)>=0.01,
C-----sigma(D-H...A)>=1.0
      ELSEIF(SX(1,I).GE..01.AND.SX(2,I).GE..01.AND.SX(3,I).GE..01.AND.
     1 SX(4,I).GE.1.) THEN
      KA=(X(4,I)+0.5)
      KX(1)=(SX(1,I)+0.005)*100
      KX(2)=(SX(2,I)+0.005)*100
      KX(3)=(SX(3,I)+0.005)*100
      KX(4)=(SX(4,I)+0.5)
      WRITE(15,106)(ATM(J,I),J=1,3),(X(K,I),KX(K),K=1,3),KA,KX(4),
     1 PE(KK(I))
106   FORMAT(3(1X,A4),F5.2,'(',I1,')',F6.2,'(',I1,')',F7.2,'(',I1,')',
     1 I5,'(',I1,')',2X,A38)
      GO TO 10
      ELSE
      WRITE(15,107)(ATM(J,I),J=1,3),(X(K,I),SX(K,I),K=1,4),PE(KK(I))
107   FORMAT(3(1X,A4),3(F6.3,'(',F4.3,')'),F6.1,'(',F3.1,')',A38)
10    ENDIF
23    CONTINUE
      GO TO 22
20    WRITE(15,'(''Error in first backspace'')')
      GO TO 22
21    WRITE(15,'(''Error in second backspace'')')
22    RETURN
      END
